<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/json/regions.json */
class __TwigTemplate_0a41e871f059d32846f57ed7eb6a01ae extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "{
\t\"United States\": [
\t\t\"Alabama\",
\t\t\"Alaska\",
\t\t\"Arizona\",
\t\t\"Arkansas\",
\t\t\"California\",
\t\t\"Colorado\",
\t\t\"Connecticut\",
\t\t\"Delaware\",
\t\t\"Florida\",
\t\t\"Georgia\",
\t\t\"Hawaii\",
\t\t\"Idaho\",
\t\t\"Illinois\",
\t\t\"Indiana\",
\t\t\"Iowa\",
\t\t\"Kansas\",
\t\t\"Kentucky\",
\t\t\"Louisiana\",
\t\t\"Maine\",
\t\t\"Maryland\",
\t\t\"Massachusetts\",
\t\t\"Michigan\",
\t\t\"Minnesota\",
\t\t\"Mississippi\",
\t\t\"Missouri\",
\t\t\"Montana\",
\t\t\"Nebraska\",
\t\t\"Nevada\",
\t\t\"New Hampshire\",
\t\t\"New Jersey\",
\t\t\"New Mexico\",
\t\t\"New York\",
\t\t\"North Carolina\",
\t\t\"North Dakota\",
\t\t\"Ohio\",
\t\t\"Oklahoma\",
\t\t\"Oregon\",
\t\t\"Pennsylvania\",
\t\t\"Rhode Island\",
\t\t\"South Carolina\",
\t\t\"South Dakota\",
\t\t\"Tennessee\",
\t\t\"Texas\",
\t\t\"Utah\",
\t\t\"Vermont\",
\t\t\"Virginia\",
\t\t\"Washington\",
\t\t\"West Virginia\",
\t\t\"Wisconsin\",
\t\t\"Wyoming\",
\t\t\"District of Columbia\",
\t\t\"American Samoa\",
\t\t\"Guam\",
\t\t\"Northern Mariana Islands\",
\t\t\"Puerto Rico\",
\t\t\"Virgin Islands\",
\t\t\"United States Minor Outlying Islands\",
\t\t\"Armed Forces Europe\",
\t\t\"Armed Forces Americas\",
\t\t\"Armed Forces Pacific\"
\t],
\t\"Liberia\": [
\t\t\"Maryland\",
\t\t\"Bomi\",
\t\t\"Bong\",
\t\t\"Grand Basaa\",
\t\t\"Grand Cape Mount\",
\t\t\"Grand Gedeh\",
\t\t\"Grand Kru\",
\t\t\"Lofa\",
\t\t\"Margibi\",
\t\t\"Montserrado\",
\t\t\"Nimba\",
\t\t\"Rivercess\",
\t\t\"Sinoe\"
\t],
\t\"Bulgaria\": [
\t\t\"Montana\",
\t\t\"Blagoevgrad\",
\t\t\"Burgas\",
\t\t\"Dobric\",
\t\t\"Gabrovo\",
\t\t\"Haskovo\",
\t\t\"Jambol\",
\t\t\"Kardzali\",
\t\t\"Kjstendil\",
\t\t\"Lovec\",
\t\t\"Pazardzik\",
\t\t\"Pernik\",
\t\t\"Pleven\",
\t\t\"Plovdiv\",
\t\t\"Razgrad\",
\t\t\"Ruse\",
\t\t\"Silistra\",
\t\t\"Sliven\",
\t\t\"Smoljan\",
\t\t\"Sofia\",
\t\t\"Stara Zagora\",
\t\t\"Sumen\",
\t\t\"Targoviste\",
\t\t\"Varna\",
\t\t\"Veliko Tarnovo\",
\t\t\"Vidin\",
\t\t\"Vraca\"
\t],
\t\"Canada\": [
\t\t\"Alberta\",
\t\t\"British Columbia\",
\t\t\"Manitoba\",
\t\t\"New Brunswick\",
\t\t\"Newfoundland and Labrador\",
\t\t\"Northwest Territories\",
\t\t\"Nova Scotia\",
\t\t\"Nunavut\",
\t\t\"Ontario\",
\t\t\"Prince Edward Island\",
\t\t\"Quebec\",
\t\t\"Saskatchewan\",
\t\t\"Yukon Territory\"
\t],
\t\"India\": [
\t\t\"Maharashtra\",
\t\t\"Karnataka\",
\t\t\"Andhra Pradesh\",
\t\t\"Arunachal Pradesh\",
\t\t\"Assam\",
\t\t\"Bihar\",
\t\t\"Chhattisgarh\",
\t\t\"Goa\",
\t\t\"Gujarat\",
\t\t\"Haryana\",
\t\t\"Himachal Pradesh\",
\t\t\"Jammu and Kashmir\",
\t\t\"Jharkhand\",
\t\t\"Kerala\",
\t\t\"Madhya Pradesh\",
\t\t\"Manipur\",
\t\t\"Meghalaya\",
\t\t\"Mizoram\",
\t\t\"Nagaland\",
\t\t\"Orissa\",
\t\t\"Punjab\",
\t\t\"Rajasthan\",
\t\t\"Sikkim\",
\t\t\"Tamil Nadu\",
\t\t\"Telangana\",
\t\t\"Tripura\",
\t\t\"Uttarakhand\",
\t\t\"Uttar Pradesh\",
\t\t\"West Bengal\",
\t\t\"Andaman and Nicobar Islands\",
\t\t\"Dadra and Nagar Haveli\",
\t\t\"Daman and Diu\",
\t\t\"Delhi\",
\t\t\"Lakshadweep\",
\t\t\"Pondicherry\"
\t],
\t\"Poland\": [
\t\t\"mazowieckie\",
\t\t\"pomorskie\",
\t\t\"dolno\\u015bl\\u0105skie\",
\t\t\"kujawsko-pomorskie\",
\t\t\"lubelskie\",
\t\t\"lubuskie\",
\t\t\"\\u0142\\u00f3dzkie\",
\t\t\"ma\\u0142opolskie\",
\t\t\"opolskie\",
\t\t\"podkarpackie\",
\t\t\"podlaskie\",
\t\t\"\\u015bl\\u0105skie\",
\t\t\"\\u015bwi\\u0119tokrzyskie\",
\t\t\"warmi\\u0144sko-mazurskie\",
\t\t\"wielkopolskie\",
\t\t\"zachodniopomorskie\"
\t],
\t\"United Arab Emirates\": [
\t\t\"Abu Zaby\",
\t\t\"'Ajman\",
\t\t\"Al Fujayrah\",
\t\t\"Ash Shariqah\",
\t\t\"Dubayy\",
\t\t\"Ra's al Khaymah\",
\t\t\"Umm al Qaywayn\"
\t],
\t\"Viet Nam\": [
\t\t\"Dac Lac\",
\t\t\"An Giang\",
\t\t\"Ba Ria - Vung Tau\",
\t\t\"Bac Can\",
\t\t\"Bac Giang\",
\t\t\"Bac Lieu\",
\t\t\"Bac Ninh\",
\t\t\"Ben Tre\",
\t\t\"Binh Dinh\",
\t\t\"Binh Duong\",
\t\t\"Binh Phuoc\",
\t\t\"Binh Thuan\",
\t\t\"Ca Mau\",
\t\t\"Can Tho\",
\t\t\"Cao Bang\",
\t\t\"Da Nang, thanh pho\",
\t\t\"Dong Nai\",
\t\t\"Dong Thap\",
\t\t\"Gia Lai\",
\t\t\"Ha Giang\",
\t\t\"Ha Nam\",
\t\t\"Ha Noi, thu do\",
\t\t\"Ha Tay\",
\t\t\"Ha Tinh\",
\t\t\"Hai Duong\",
\t\t\"Hai Phong, thanh pho\",
\t\t\"Hoa Binh\",
\t\t\"Ho Chi Minh, thanh pho [Sai Gon]\",
\t\t\"Hung Yen\",
\t\t\"Khanh Hoa\",
\t\t\"Kien Giang\",
\t\t\"Kon Tum\",
\t\t\"Lai Chau\",
\t\t\"Lam Dong\",
\t\t\"Lang Son\",
\t\t\"Lao Cai\",
\t\t\"Long An\",
\t\t\"Nam Dinh\",
\t\t\"Nghe An\",
\t\t\"Ninh Binh\",
\t\t\"Ninh Thuan\",
\t\t\"Phu Tho\",
\t\t\"Phu Yen\",
\t\t\"Quang Binh\",
\t\t\"Quang Nam\",
\t\t\"Quang Ngai\",
\t\t\"Quang Ninh\",
\t\t\"Quang Tri\",
\t\t\"Soc Trang\",
\t\t\"Son La\",
\t\t\"Tay Ninh\",
\t\t\"Thai Binh\",
\t\t\"Thai Nguyen\",
\t\t\"Thanh Hoa\",
\t\t\"Thua Thien-Hue\",
\t\t\"Tien Giang\",
\t\t\"Tra Vinh\",
\t\t\"Tuyen Quang\",
\t\t\"Vinh Long\",
\t\t\"Vinh Phuc\",
\t\t\"Yen Bai\"
\t],
\t\"Afghanistan\": [
\t\t\"Badakhshan\",
\t\t\"Badghis\",
\t\t\"Baghlan\",
\t\t\"Balkh\",
\t\t\"Bamian\",
\t\t\"Farah\",
\t\t\"Faryab\",
\t\t\"Ghazni\",
\t\t\"Ghowr\",
\t\t\"Helmand\",
\t\t\"Herat\",
\t\t\"Jowzjan\",
\t\t\"Kabul\",
\t\t\"Kandahar\",
\t\t\"Kapisa\",
\t\t\"Khowst\",
\t\t\"Konar\",
\t\t\"Kondoz\",
\t\t\"Laghman\",
\t\t\"Lowgar\",
\t\t\"Nangrahar\",
\t\t\"Nimruz\",
\t\t\"Nurestan\",
\t\t\"Oruzgan\",
\t\t\"Paktia\",
\t\t\"Paktika\",
\t\t\"Parwan\",
\t\t\"Samangan\",
\t\t\"Sar-e Pol\",
\t\t\"Takhar\",
\t\t\"Wardak\",
\t\t\"Zabol\"
\t],
\t\"Albania\": [
\t\t\"Berat\",
\t\t\"Bulqiz\\u00eb\",
\t\t\"Delvin\\u00eb\",
\t\t\"Devoll\",
\t\t\"Dib\\u00ebr\",
\t\t\"Durrs\\u00ebs\",
\t\t\"Elbasan\",
\t\t\"Fier\",
\t\t\"Gramsh\",
\t\t\"Gjirokast\\u00ebr\",
\t\t\"Has\",
\t\t\"Kavaj\\u00eb\",
\t\t\"Kolonj\\u00eb\",
\t\t\"Korc\\u00eb\",
\t\t\"Kruj\\u00eb\",
\t\t\"Ku\\u00e7ov\\u00eb\",
\t\t\"Kuk\\u00ebs\",
\t\t\"Kurbin\",
\t\t\"Lezh\\u00eb\",
\t\t\"Librazhd\",
\t\t\"Lushnj\\u00eb\",
\t\t\"Mal\\u00ebsi e Madhe\",
\t\t\"Mallakast\\u00ebr\",
\t\t\"Mat\",
\t\t\"Mirdit\\u00eb\",
\t\t\"Peqin\",
\t\t\"P\\u00ebrmet\",
\t\t\"Pogradec\",
\t\t\"Puk\\u00eb\",
\t\t\"Sarand\\u00eb\",
\t\t\"Skrapar\",
\t\t\"Shkod\\u00ebr\",
\t\t\"Tepelen\\u00eb\",
\t\t\"Tiran\\u00eb\",
\t\t\"Tropoj\\u00eb\",
\t\t\"Vlor\\u00eb\"
\t],
\t\"Armenia\": [
\t\t\"Erevan\",
\t\t\"Aragacotn\",
\t\t\"Ararat\",
\t\t\"Armavir\",
\t\t\"Gegarkunik'\",
\t\t\"Kotayk'\",
\t\t\"Lory\",
\t\t\"Sirak\",
\t\t\"Syunik'\",
\t\t\"Tavus\",
\t\t\"Vayoc Jor\"
\t],
\t\"Angola\": [
\t\t\"Bengo\",
\t\t\"Benguela\",
\t\t\"Bie\",
\t\t\"Cabinda\",
\t\t\"Cuando-Cubango\",
\t\t\"Cuanza Norte\",
\t\t\"Cuanza Sul\",
\t\t\"Cunene\",
\t\t\"Huambo\",
\t\t\"Huila\",
\t\t\"Luanda\",
\t\t\"Lunda Norte\",
\t\t\"Lunda Sul\",
\t\t\"Malange\",
\t\t\"Moxico\",
\t\t\"Namibe\",
\t\t\"Uige\",
\t\t\"Zaire\"
\t],
\t\"Argentina\": [
\t\t\"Capital federal\",
\t\t\"Buenos Aires\",
\t\t\"Catamarca\",
\t\t\"Cordoba\",
\t\t\"Corrientes\",
\t\t\"Chaco\",
\t\t\"Chubut\",
\t\t\"Entre Rios\",
\t\t\"Formosa\",
\t\t\"Jujuy\",
\t\t\"La Pampa\",
\t\t\"La Rioja\",
\t\t\"Mendoza\",
\t\t\"Misiones\",
\t\t\"Neuquen\",
\t\t\"Rio Negro\",
\t\t\"Salta\",
\t\t\"San Juan\",
\t\t\"San Luis\",
\t\t\"Santa Cruz\",
\t\t\"Santa Fe\",
\t\t\"Santiago del Estero\",
\t\t\"Tierra del Fuego\",
\t\t\"Tucuman\"
\t],
\t\"Austria\": [
\t\t\"Burgenland\",
\t\t\"K\\u00e4rnten\",
\t\t\"Nieder\\u00f6sterreich\",
\t\t\"Ober\\u00f6sterreich\",
\t\t\"Salzburg\",
\t\t\"Steiermark\",
\t\t\"Tirol\",
\t\t\"Vorarlberg\",
\t\t\"Wien\"
\t],
\t\"Antarctica\": [
\t\t\"Australian Antarctic Territory\"
\t],
\t\"Australia\": [
\t\t\"Australian Capital Territory\",
\t\t\"Northern Territory\",
\t\t\"New South Wales\",
\t\t\"Queensland\",
\t\t\"South Australia\",
\t\t\"Tasmania\",
\t\t\"Victoria\",
\t\t\"Western Australia\"
\t],
\t\"Azerbaijan\": [
\t\t\"Naxcivan\",
\t\t\"Ali Bayramli\",
\t\t\"Baki\",
\t\t\"Ganca\",
\t\t\"Lankaran\",
\t\t\"Mingacevir\",
\t\t\"Naftalan\",
\t\t\"Saki\",
\t\t\"Sumqayit\",
\t\t\"Susa\",
\t\t\"Xankandi\",
\t\t\"Yevlax\",
\t\t\"Abseron\",
\t\t\"Agcabadi\",
\t\t\"Agdam\",
\t\t\"Agdas\",
\t\t\"Agstafa\",
\t\t\"Agsu\",
\t\t\"Astara\",
\t\t\"Babak\",
\t\t\"Balakan\",
\t\t\"Barda\",
\t\t\"Beylagan\",
\t\t\"Bilasuvar\",
\t\t\"Cabrayll\",
\t\t\"Calilabad\",
\t\t\"Culfa\",
\t\t\"Daskasan\",
\t\t\"Davaci\",
\t\t\"Fuzuli\",
\t\t\"Gadabay\",
\t\t\"Goranboy\",
\t\t\"Goycay\",
\t\t\"Haciqabul\",
\t\t\"Imisli\",
\t\t\"Ismayilli\",
\t\t\"Kalbacar\",
\t\t\"Kurdamir\",
\t\t\"Lacin\",
\t\t\"Lerik\",
\t\t\"Masalli\",
\t\t\"Neftcala\",
\t\t\"Oguz\",
\t\t\"Ordubad\",
\t\t\"Qabala\",
\t\t\"Qax\",
\t\t\"Qazax\",
\t\t\"Qobustan\",
\t\t\"Quba\",
\t\t\"Qubadli\",
\t\t\"Qusar\",
\t\t\"Saatli\",
\t\t\"Sabirabad\",
\t\t\"Sadarak\",
\t\t\"Sahbuz\",
\t\t\"Salyan\",
\t\t\"Samaxi\",
\t\t\"Samkir\",
\t\t\"Samux\",
\t\t\"Sarur\",
\t\t\"Siyazan\",
\t\t\"Tartar\",
\t\t\"Tovuz\",
\t\t\"Ucar\",
\t\t\"Xacmaz\",
\t\t\"Xanlar\",
\t\t\"Xizi\",
\t\t\"Xocali\",
\t\t\"Xocavand\",
\t\t\"Yardimli\",
\t\t\"Zangilan\",
\t\t\"Zaqatala\",
\t\t\"Zardab\"
\t],
\t\"Bosnia and Herzegovina\": [
\t\t\"Federacija Bosna i Hercegovina\",
\t\t\"Republika Srpska\"
\t],
\t\"Bangladesh\": [
\t\t\"Bagerhat zila\",
\t\t\"Bandarban zila\",
\t\t\"Barguna zila\",
\t\t\"Barisal zila\",
\t\t\"Bhola zila\",
\t\t\"Bogra zila\",
\t\t\"Brahmanbaria zila\",
\t\t\"Chandpur zila\",
\t\t\"Chittagong zila\",
\t\t\"Chuadanga zila\",
\t\t\"Comilla zila\",
\t\t\"Cox's Bazar zila\",
\t\t\"Dhaka zila\",
\t\t\"Dinajpur zila\",
\t\t\"Faridpur zila\",
\t\t\"Feni zila\",
\t\t\"Gaibandha zila\",
\t\t\"Gazipur zila\",
\t\t\"Gopalganj zila\",
\t\t\"Habiganj zila\",
\t\t\"Jaipurhat zila\",
\t\t\"Jamalpur zila\",
\t\t\"Jessore zila\",
\t\t\"Jhalakati zila\",
\t\t\"Jhenaidah zila\",
\t\t\"Khagrachari zila\",
\t\t\"Khulna zila\",
\t\t\"Kishorganj zila\",
\t\t\"Kurigram zila\",
\t\t\"Kushtia zila\",
\t\t\"Lakshmipur zila\",
\t\t\"Lalmonirhat zila\",
\t\t\"Madaripur zila\",
\t\t\"Magura zila\",
\t\t\"Manikganj zila\",
\t\t\"Meherpur zila\",
\t\t\"Moulvibazar zila\",
\t\t\"Munshiganj zila\",
\t\t\"Mymensingh zila\",
\t\t\"Naogaon zila\",
\t\t\"Narail zila\",
\t\t\"Narayanganj zila\",
\t\t\"Narsingdi zila\",
\t\t\"Natore zila\",
\t\t\"Nawabganj zila\",
\t\t\"Netrakona zila\",
\t\t\"Nilphamari zila\",
\t\t\"Noakhali zila\",
\t\t\"Pabna zila\",
\t\t\"Panchagarh zila\",
\t\t\"Patuakhali zila\",
\t\t\"Pirojpur zila\",
\t\t\"Rajbari zila\",
\t\t\"Rajshahi zila\",
\t\t\"Rangamati zila\",
\t\t\"Rangpur zila\",
\t\t\"Satkhira zila\",
\t\t\"Shariatpur zila\",
\t\t\"Sherpur zila\",
\t\t\"Sirajganj zila\",
\t\t\"Sunamganj zila\",
\t\t\"Sylhet zila\",
\t\t\"Tangail zila\",
\t\t\"Thakurgaon zila\"
\t],
\t\"Belgium\": [
\t\t\"Antwerpen\",
\t\t\"Brabant Wallon\",
\t\t\"Hainaut\",
\t\t\"Liege\",
\t\t\"Luxembourg\",
\t\t\"Namur\",
\t\t\"Oost-Vlaanderen\",
\t\t\"Vlaams-Brabant\",
\t\t\"West-Vlaanderen\",
\t\t\"Brussels\"
\t],
\t\"Netherlands\": [
\t\t\"Limburg\",
\t\t\"Drente\",
\t\t\"Flevoland\",
\t\t\"Friesland\",
\t\t\"Gelderland\",
\t\t\"Groningen\",
\t\t\"Noord-Brabant\",
\t\t\"Noord-Holland\",
\t\t\"Overijssel\",
\t\t\"Utrecht\",
\t\t\"Zuid-Holland\",
\t\t\"Zeeland\"
\t],
\t\"Burkina Faso\": [
\t\t\"Bale\",
\t\t\"Bam\",
\t\t\"Banwa\",
\t\t\"Bazega\",
\t\t\"Bougouriba\",
\t\t\"Boulgou\",
\t\t\"Boulkiemde\",
\t\t\"Comoe\",
\t\t\"Ganzourgou\",
\t\t\"Gnagna\",
\t\t\"Gourma\",
\t\t\"Houet\",
\t\t\"Ioba\",
\t\t\"Kadiogo\",
\t\t\"Kenedougou\",
\t\t\"Komondjari\",
\t\t\"Kompienga\",
\t\t\"Kossi\",
\t\t\"Koulpulogo\",
\t\t\"Kouritenga\",
\t\t\"Kourweogo\",
\t\t\"Leraba\",
\t\t\"Loroum\",
\t\t\"Mouhoun\",
\t\t\"Nahouri\",
\t\t\"Namentenga\",
\t\t\"Nayala\",
\t\t\"Noumbiel\",
\t\t\"Oubritenga\",
\t\t\"Oudalan\",
\t\t\"Passore\",
\t\t\"Poni\",
\t\t\"Sanguie\",
\t\t\"Sanmatenga\",
\t\t\"Seno\",
\t\t\"Siasili\",
\t\t\"Soum\",
\t\t\"Sourou\",
\t\t\"Tapoa\",
\t\t\"Tui\",
\t\t\"Yagha\",
\t\t\"Yatenga\",
\t\t\"Ziro\",
\t\t\"Zondoma\",
\t\t\"Zoundweogo\"
\t],
\t\"Bahrain\": [
\t\t\"Al Hadd\",
\t\t\"Al Manamah\",
\t\t\"Al Mintaqah al Gharbiyah\",
\t\t\"Al Mintagah al Wusta\",
\t\t\"Al Mintaqah ash Shamaliyah\",
\t\t\"Al Muharraq\",
\t\t\"Ar Rifa\",
\t\t\"Jidd Hafs\",
\t\t\"Madluat Jamad\",
\t\t\"Madluat Isa\",
\t\t\"Mintaqat Juzur tawar\",
\t\t\"Sitrah\",
\t\t\"Al Man\\u0101mah (Al \\u2018\\u0100\\u015fimah)\",
\t\t\"Al Jan\\u016bb\\u012byah\",
\t\t\"Al Wus\\u0163\\u00e1\",
\t\t\"Ash Sham\\u0101l\\u012byah\"
\t],
\t\"Burundi\": [
\t\t\"Bubanza\",
\t\t\"Bujumbura\",
\t\t\"Bururi\",
\t\t\"Cankuzo\",
\t\t\"Cibitoke\",
\t\t\"Gitega\",
\t\t\"Karuzi\",
\t\t\"Kayanza\",
\t\t\"Makamba\",
\t\t\"Muramvya\",
\t\t\"Mwaro\",
\t\t\"Ngozi\",
\t\t\"Rutana\",
\t\t\"Ruyigi\"
\t],
\t\"Benin\": [
\t\t\"Alibori\",
\t\t\"Atakora\",
\t\t\"Atlantique\",
\t\t\"Borgou\",
\t\t\"Collines\",
\t\t\"Donga\",
\t\t\"Kouffo\",
\t\t\"Littoral\",
\t\t\"Mono\",
\t\t\"Oueme\",
\t\t\"Plateau\",
\t\t\"Zou\"
\t],
\t\"Brunei Darussalam\": [
\t\t\"Belait\",
\t\t\"Brunei-Muara\",
\t\t\"Temburong\",
\t\t\"Tutong\"
\t],
\t\"Bolivia\": [
\t\t\"Cochabamba\",
\t\t\"Chuquisaca\",
\t\t\"El Beni\",
\t\t\"La Paz\",
\t\t\"Oruro\",
\t\t\"Pando\",
\t\t\"Potosi\",
\t\t\"Tarija\"
\t],
\t\"Brazil\": [
\t\t\"Acre\",
\t\t\"Alagoas\",
\t\t\"Amazonas\",
\t\t\"Amapa\",
\t\t\"Bahia\",
\t\t\"Ceara\",
\t\t\"Distrito Federal\",
\t\t\"Espirito Santo\",
\t\t\"Goias\",
\t\t\"Maranhao\",
\t\t\"Minas Gerais\",
\t\t\"Mato Grosso do Sul\",
\t\t\"Mato Grosso\",
\t\t\"Para\",
\t\t\"Paraiba\",
\t\t\"Pernambuco\",
\t\t\"Piaui\",
\t\t\"Parana\",
\t\t\"Rio de Janeiro\",
\t\t\"Rio Grande do Norte\",
\t\t\"Rondonia\",
\t\t\"Roraima\",
\t\t\"Rio Grande do Sul\",
\t\t\"Santa Catarina\",
\t\t\"Sergipe\",
\t\t\"Sao Paulo\",
\t\t\"Tocantins\"
\t],
\t\"Mexico\": [
\t\t\"Aguascalientes\",
\t\t\"Baja California\",
\t\t\"Baja California Sur\",
\t\t\"Campeche\",
\t\t\"Ciudad de M\\u00e9xico\",
\t\t\"Coahuila\",
\t\t\"Colima\",
\t\t\"Chiapas\",
\t\t\"Chihuahua\",
\t\t\"Durango\",
\t\t\"Guanajuato\",
\t\t\"Guerrero\",
\t\t\"Hidalgo\",
\t\t\"Jalisco\",
\t\t\"Estado de M\\u00e9xico\",
\t\t\"Michoac\\u00e1n\",
\t\t\"Morelos\",
\t\t\"Nayarit\",
\t\t\"Nuevo Le\\u00f3n\",
\t\t\"Oaxaca\",
\t\t\"Puebla\",
\t\t\"Quer\\u00e9taro\",
\t\t\"Quintana Roo\",
\t\t\"San Luis Potos\\u00ed\",
\t\t\"Sinaloa\",
\t\t\"Sonora\",
\t\t\"Tabasco\",
\t\t\"Tamaulipas\",
\t\t\"Tlaxcala\",
\t\t\"Veracruz\",
\t\t\"Yucat\\u00e1n\",
\t\t\"Zacatecas\"
\t],
\t\"Bahamas\": [
\t\t\"Acklins and Crooked Islands\",
\t\t\"Bimini\",
\t\t\"Cat Island\",
\t\t\"Exuma\",
\t\t\"Freeport\",
\t\t\"Fresh Creek\",
\t\t\"Governor's Harbour\",
\t\t\"Green Turtle Cay\",
\t\t\"Harbour Island\",
\t\t\"High Rock\",
\t\t\"Inagua\",
\t\t\"Kemps Bay\",
\t\t\"Long Island\",
\t\t\"Marsh Harbour\",
\t\t\"Mayaguana\",
\t\t\"New Providence\",
\t\t\"Nicholls Town and Berry Islands\",
\t\t\"Ragged Island\",
\t\t\"Rock Sound\",
\t\t\"Sandy Point\",
\t\t\"San Salvador and Rum Cay\"
\t],
\t\"Bhutan\": [
\t\t\"Bumthang\",
\t\t\"Chhukha\",
\t\t\"Dagana\",
\t\t\"Gasa\",
\t\t\"Ha\",
\t\t\"Lhuentse\",
\t\t\"Monggar\",
\t\t\"Paro\",
\t\t\"Pemagatshel\",
\t\t\"Punakha\",
\t\t\"Samdrup Jongkha\",
\t\t\"Samtee\",
\t\t\"Sarpang\",
\t\t\"Thimphu\",
\t\t\"Trashigang\",
\t\t\"Trashi Yangtse\",
\t\t\"Trongsa\",
\t\t\"Tsirang\",
\t\t\"Wangdue Phodrang\",
\t\t\"Zhemgang\"
\t],
\t\"Botswana\": [
\t\t\"Central\",
\t\t\"Ghanzi\",
\t\t\"Kgalagadi\",
\t\t\"Kgatleng\",
\t\t\"Kweneng\",
\t\t\"Ngamiland\",
\t\t\"North-East\",
\t\t\"North-West\",
\t\t\"South-East\"
\t],
\t\"Hong Kong\": [
\t\t\"Southern\",
\t\t\"North\",
\t\t\"Eastern\",
\t\t\"Central and Western\",
\t\t\"Wan Chai\",
\t\t\"Kowloon City\",
\t\t\"Kwun Tong\",
\t\t\"Sham Shui Po\",
\t\t\"Wong Tai Sin\",
\t\t\"Yau Tsim Mong\",
\t\t\"Islands\",
\t\t\"Kwai Tsing\",
\t\t\"Sai Kung\",
\t\t\"Sha Tin\",
\t\t\"Tai Po\",
\t\t\"Tsuen Wan\",
\t\t\"Tuen Mun\",
\t\t\"Yuen Long\"
\t],
\t\"Belarus\": [
\t\t\"Br\\u00e8sckaja voblasc'\",
\t\t\"Homel'skaja voblasc'\",
\t\t\"Hrodzenskaja voblasc'\",
\t\t\"Mahil\\u00ebuskaja voblasc'\",
\t\t\"Minskaja voblasc'\",
\t\t\"Vicebskaja voblasc'\"
\t],
\t\"Belize\": [
\t\t\"Belize\",
\t\t\"Cayo\",
\t\t\"Corozal\",
\t\t\"Orange Walk\",
\t\t\"Stann Creek\",
\t\t\"Toledo\"
\t],
\t\"Congo, The Democratic Republic of the\": [
\t\t\"Kinshasa\",
\t\t\"Bandundu\",
\t\t\"Bas-Congo\",
\t\t\"Equateur\",
\t\t\"Haut-Congo\",
\t\t\"Kasai-Occidental\",
\t\t\"Kasai-Oriental\",
\t\t\"Katanga\",
\t\t\"Maniema\",
\t\t\"Nord-Kivu\",
\t\t\"Orientale\",
\t\t\"Sud-Kivu\"
\t],
\t\"Central African Republic\": [
\t\t\"Bangui\",
\t\t\"Bamingui-Bangoran\",
\t\t\"Basse-Kotto\",
\t\t\"Haute-Kotto\",
\t\t\"Haut-Mbomou\",
\t\t\"Kemo\",
\t\t\"Lobaye\",
\t\t\"Mambere-Kadei\",
\t\t\"Mbomou\",
\t\t\"Nana-Grebizi\",
\t\t\"Nana-Mambere\",
\t\t\"Ombella-Mpoko\",
\t\t\"Ouaka\",
\t\t\"Ouham\",
\t\t\"Ouham-Pende\",
\t\t\"Sangha-Mbaere\",
\t\t\"Vakaga\"
\t],
\t\"Congo\": [
\t\t\"Brazzaville\",
\t\t\"Bouenza\",
\t\t\"Cuvette\",
\t\t\"Cuvette-Ouest\",
\t\t\"Kouilou\",
\t\t\"Lekoumou\",
\t\t\"Likouala\",
\t\t\"Niari\",
\t\t\"Plateaux\",
\t\t\"Pool\",
\t\t\"Sangha\"
\t],
\t\"Switzerland\": [
\t\t\"Aargau\",
\t\t\"Appenzell Innerrhoden\",
\t\t\"Appenzell Ausserrhoden\",
\t\t\"Bern\",
\t\t\"Basel-Landschaft\",
\t\t\"Basel-Stadt\",
\t\t\"Fribourg\",
\t\t\"Gen\\u00e8ve\",
\t\t\"Glarus\",
\t\t\"Graub\\u00fcnden\",
\t\t\"Jura\",
\t\t\"Luzern\",
\t\t\"Neuch\\u00e2tel\",
\t\t\"Nidwalden\",
\t\t\"Obwalden\",
\t\t\"St. Gallen\",
\t\t\"Schaffhausen\",
\t\t\"Solothurn\",
\t\t\"Schwyz\",
\t\t\"Thurgau\",
\t\t\"Ticino\",
\t\t\"Uri\",
\t\t\"Vaud\",
\t\t\"Valais\",
\t\t\"Zug\",
\t\t\"Z\\u00fcrich\"
\t],
\t\"France\": [
\t\t\"Auvergne-Rhône-Alpes\",
\t\t\"Bourgogne-Franche-Comté\",
\t\t\"Bretagne\",
\t\t\"Centre-Val de Loire\",
\t\t\"Corse\",
\t\t\"Grand Est\",
\t\t\"Hauts-de-France\",
\t\t\"Île-de-France\",
\t\t\"Normandie\",
\t\t\"Nouvelle-Aquitaine\",
\t\t\"Occitanie\",
\t\t\"Pays de la Loire\",
\t\t\"Provence-Alpes-Côte d'Azur\",
\t\t\"Ain\",
\t\t\"Aisne\",
\t\t\"Allier\",
\t\t\"Alpes-de-Haute-Provence\",
\t\t\"Hautes-Alpes\",
\t\t\"Alpes-Maritimes\",
\t\t\"Ardèche\",
\t\t\"Ardennes\",
\t\t\"Ariège\",
\t\t\"Aube\",
\t\t\"Aude\",
\t\t\"Aveyron\",
\t\t\"Bouches-du-Rhône\",
\t\t\"Calvados\",
\t\t\"Cantal\",
\t\t\"Charente\",
\t\t\"Charente-Maritime\",
\t\t\"Cher\",
\t\t\"Corrèze\",
\t\t\"Corse-du-Sud\",
\t\t\"Haute-Corse\",
\t\t\"Côte-d'Or\",
\t\t\"Côtes-d'Armor\",
\t\t\"Creuse\",
\t\t\"Dordogne\",
\t\t\"Doubs\",
\t\t\"Drôme\",
\t\t\"Eure\",
\t\t\"Eure-et-Loir\",
\t\t\"Finistère\",
\t\t\"Gard\",
\t\t\"Haute-Garonne\",
\t\t\"Gers\",
\t\t\"Gironde\",
\t\t\"Hérault\",
\t\t\"Ille-et-Vilaine\",
\t\t\"Indre\",
\t\t\"Indre-et-Loire\",
\t\t\"Isère\",
\t\t\"Jura\",
\t\t\"Landes\",
\t\t\"Loir-et-Cher\",
\t\t\"Loire\",
\t\t\"Haute-Loire\",
\t\t\"Loire-Atlantique\",
\t\t\"Loiret\",
\t\t\"Lot\",
\t\t\"Lot-et-Garonne\",
\t\t\"Lozère\",
\t\t\"Maine-et-Loire\",
\t\t\"Manche\",
\t\t\"Marne\",
\t\t\"Haute-Marne\",
\t\t\"Mayenne\",
\t\t\"Meurthe-et-Moselle\",
\t\t\"Meuse\",
\t\t\"Morbihan\",
\t\t\"Moselle\",
\t\t\"Nièvre\",
\t\t\"Nord\",
\t\t\"Oise\",
\t\t\"Orne\",
\t\t\"Pas-de-Calais\",
\t\t\"Puy-de-Dôme\",
\t\t\"Pyrénées-Atlantiques\",
\t\t\"Hautes-Pyrénées\",
\t\t\"Pyrénées-Orientales\",
\t\t\"Bas-Rhin\",
\t\t\"Haut-Rhin\",
\t\t\"Rhône\",
\t\t\"Haute-Saône\",
\t\t\"Saône-et-Loire\",
\t\t\"Sarthe\",
\t\t\"Savoie\",
\t\t\"Haute-Savoie\",
\t\t\"Paris\",
\t\t\"Seine-Maritime\",
\t\t\"Seine-et-Marne\",
\t\t\"Yvelines\",
\t\t\"Deux-Sèvres\",
\t\t\"Somme\",
\t\t\"Tarn\",
\t\t\"Tarn-et-Garonne\",
\t\t\"Var\",
\t\t\"Vaucluse\",
\t\t\"Vendée\",
\t\t\"Vienne\",
\t\t\"Haute-Vienne\",
\t\t\"Vosges\",
\t\t\"Yonne\",
\t\t\"Territoire de Belfort\",
\t\t\"Essonne\",
\t\t\"Hauts-de-Seine\",
\t\t\"Seine-Saint-Denis\",
\t\t\"Val-de-Marne\",
\t\t\"Val-d'Oise\",
\t\t\"Guadeloupe\",
\t\t\"Guyane\",
\t\t\"Martinique\",
\t\t\"La Réunion\",
\t\t\"Mayotte\"
\t],
\t\"C\\u00f4te d'Ivoire\": [
\t\t\"18 Montagnes\",
\t\t\"Agnebi\",
\t\t\"Bas-Sassandra\",
\t\t\"Denguele\",
\t\t\"Haut-Sassandra\",
\t\t\"Lacs\",
\t\t\"Lagunes\",
\t\t\"Marahoue\",
\t\t\"Moyen-Comoe\",
\t\t\"Nzi-Comoe\",
\t\t\"Savanes\",
\t\t\"Sud-Bandama\",
\t\t\"Sud-Comoe\",
\t\t\"Vallee du Bandama\",
\t\t\"Worodouqou\",
\t\t\"Zanzan\"
\t],
\t\"Chile\": [
\t\t\"Aisen del General Carlos Ibanez del Campo\",
\t\t\"Antofagasta\",
\t\t\"Araucania\",
\t\t\"Atacama\",
\t\t\"Bio-Bio\",
\t\t\"Coquimbo\",
\t\t\"Libertador General Bernardo O'Higgins\",
\t\t\"Los Lagos\",
\t\t\"Magallanes\",
\t\t\"Maule\",
\t\t\"Region Metropolitana de Santiago\",
\t\t\"Tarapaca\",
\t\t\"Valparaiso\"
\t],
\t\"Cameroon\": [
\t\t\"Adamaoua\",
\t\t\"East\",
\t\t\"Far North\",
\t\t\"South\",
\t\t\"South-West\",
\t\t\"West\"
\t],
\t\"Haiti\": [
\t\t\"Centre\",
\t\t\"Nord\",
\t\t\"Grande-Anse\",
\t\t\"Nord-Est\",
\t\t\"Nord-Ouest\",
\t\t\"Ouest\",
\t\t\"Sud\",
\t\t\"Sud-Est\",
\t\t\"Artibonite\",
\t\t\"Nippes\"
\t],
\t\"China\": [
\t\t\"Beijing\",
\t\t\"Chongqing\",
\t\t\"Shanghai\",
\t\t\"Tianjin\",
\t\t\"Anhui\",
\t\t\"Fujian\",
\t\t\"Gansu\",
\t\t\"Guangdong\",
\t\t\"Guizhou\",
\t\t\"Hainan\",
\t\t\"Hebei\",
\t\t\"Heilongjiang\",
\t\t\"Henan\",
\t\t\"Hubei\",
\t\t\"Hunan\",
\t\t\"Jiangsu\",
\t\t\"Jiangxi\",
\t\t\"Jilin\",
\t\t\"Liaoning\",
\t\t\"Qinghai\",
\t\t\"Shaanxi\",
\t\t\"Shandong\",
\t\t\"Shanxi\",
\t\t\"Sichuan\",
\t\t\"Taiwan\",
\t\t\"Yunnan\",
\t\t\"Zhejiang\",
\t\t\"Guangxi\",
\t\t\"Neia Mongol (mn)\",
\t\t\"Xinjiang\",
\t\t\"Xizang\",
\t\t\"Hong Kong\",
\t\t\"Macau\"
\t],
\t\"Colombia\": [
\t\t\"Distrito Capital de Bogot\\u00e1\",
\t\t\"Amazonea\",
\t\t\"Antioquia\",
\t\t\"Arauca\",
\t\t\"Atl\\u00e1ntico\",
\t\t\"Bol\\u00edvar\",
\t\t\"Boyac\\u00e1\",
\t\t\"Caldea\",
\t\t\"Caquet\\u00e1\",
\t\t\"Casanare\",
\t\t\"Cauca\",
\t\t\"Cesar\",
\t\t\"C\\u00f3rdoba\",
\t\t\"Cundinamarca\",
\t\t\"Choc\\u00f3\",
\t\t\"Guain\\u00eda\",
\t\t\"Guaviare\",
\t\t\"La Guajira\",
\t\t\"Magdalena\",
\t\t\"Meta\",
\t\t\"Nari\\u00f1o\",
\t\t\"Norte de Santander\",
\t\t\"Putumayo\",
\t\t\"Quindio\",
\t\t\"Risaralda\",
\t\t\"San Andr\\u00e9s, Providencia y Santa Catalina\",
\t\t\"Santander\",
\t\t\"Sucre\",
\t\t\"Tolima\",
\t\t\"Valle del Cauca\",
\t\t\"Vaup\\u00e9s\",
\t\t\"Vichada\"
\t],
\t\"Costa Rica\": [
\t\t\"Alajuela\",
\t\t\"Cartago\",
\t\t\"Guanacaste\",
\t\t\"Heredia\",
\t\t\"Limon\",
\t\t\"Puntarenas\",
\t\t\"San Jose\"
\t],
\t\"Cuba\": [
\t\t\"Camagey\",
\t\t\"Ciego de `vila\",
\t\t\"Cienfuegos\",
\t\t\"Ciudad de La Habana\",
\t\t\"Granma\",
\t\t\"Guantanamo\",
\t\t\"Holquin\",
\t\t\"La Habana\",
\t\t\"Las Tunas\",
\t\t\"Matanzas\",
\t\t\"Pinar del Rio\",
\t\t\"Sancti Spiritus\",
\t\t\"Santiago de Cuba\",
\t\t\"Villa Clara\",
\t\t\"Isla de la Juventud\",
\t\t\"Pinar del Roo\",
\t\t\"Ciego de Avila\",
\t\t\"Camagoey\",
\t\t\"Holgun\",
\t\t\"Sancti Spritus\",
\t\t\"Municipio Especial Isla de la Juventud\"
\t],
\t\"Cape Verde\": [
\t\t\"Boa Vista\",
\t\t\"Brava\",
\t\t\"Calheta de Sao Miguel\",
\t\t\"Fogo\",
\t\t\"Maio\",
\t\t\"Mosteiros\",
\t\t\"Paul\",
\t\t\"Porto Novo\",
\t\t\"Praia\",
\t\t\"Ribeira Grande\",
\t\t\"Sal\",
\t\t\"Sao Domingos\",
\t\t\"Sao Filipe\",
\t\t\"Sao Nicolau\",
\t\t\"Sao Vicente\",
\t\t\"Tarrafal\"
\t],
\t\"Cyprus\": [
\t\t\"Ammochostos Magusa\",
\t\t\"Keryneia\",
\t\t\"Larnaka\",
\t\t\"Lefkosia\",
\t\t\"Lemesos\",
\t\t\"Pafos\"
\t],
\t\"Czech Republic\": [
\t\t\"Jiho\\u010desk\\u00fd kraj\",
\t\t\"Jihomoravsk\\u00fd kraj\",
\t\t\"Karlovarsk\\u00fd kraj\",
\t\t\"Kr\\u00e1lov\\u00e9hradeck\\u00fd kraj\",
\t\t\"Libereck\\u00fd kraj\",
\t\t\"Moravskoslezsk\\u00fd kraj\",
\t\t\"Olomouck\\u00fd kraj\",
\t\t\"Pardubick\\u00fd kraj\",
\t\t\"Plze\\u0148sk\\u00fd kraj\",
\t\t\"Praha, hlavn\\u00ed m\\u011bsto\",
\t\t\"St\\u0159edo\\u010desk\\u00fd kraj\",
\t\t\"\\u00dasteck\\u00fd kraj\",
\t\t\"Vyso\\u010dina\",
\t\t\"Zl\\u00ednsk\\u00fd kraj\"
\t],
\t\"Germany\": [
\t\t\"Baden-W\\u00fcrttemberg\",
\t\t\"Bayern\",
\t\t\"Bremen\",
\t\t\"Hamburg\",
\t\t\"Hessen\",
\t\t\"Niedersachsen\",
\t\t\"Nordrhein-Westfalen\",
\t\t\"Rheinland-Pfalz\",
\t\t\"Saarland\",
\t\t\"Schleswig-Holstein\",
\t\t\"Berlin\",
\t\t\"Brandenburg\",
\t\t\"Mecklenburg-Vorpommern\",
\t\t\"Sachsen\",
\t\t\"Sachsen-Anhalt\",
\t\t\"Th\\u00fcringen\"
\t],
\t\"Djibouti\": [
\t\t\"Ali Sabiah\",
\t\t\"Dikhil\",
\t\t\"Djibouti\",
\t\t\"Obock\",
\t\t\"Tadjoura\"
\t],
\t\"Denmark\": [
\t\t\"Frederiksberg\",
\t\t\"Copenhagen City\",
\t\t\"Copenhagen\",
\t\t\"Frederiksborg\",
\t\t\"Roskilde\",
\t\t\"Vestsj\\u00e6lland\",
\t\t\"Storstr\\u00f8m\",
\t\t\"Bornholm\",
\t\t\"Fyn\",
\t\t\"South Jutland\",
\t\t\"Ribe\",
\t\t\"Vejle\",
\t\t\"Ringkj\\u00f8bing\",
\t\t\"\\u00c5rhus\",
\t\t\"Viborg\",
\t\t\"North Jutland\"
\t],
\t\"Dominican Republic\": [
\t\t\"Distrito Nacional (Santo Domingo)\",
\t\t\"Azua\",
\t\t\"Bahoruco\",
\t\t\"Barahona\",
\t\t\"Dajab\\u00f3n\",
\t\t\"Duarte\",
\t\t\"El Seybo [El Seibo]\",
\t\t\"Espaillat\",
\t\t\"Hato Mayor\",
\t\t\"Independencia\",
\t\t\"La Altagracia\",
\t\t\"La Estrelleta [Elias Pina]\",
\t\t\"La Romana\",
\t\t\"La Vega\",
\t\t\"Maroia Trinidad S\\u00e1nchez\",
\t\t\"Monse\\u00f1or Nouel\",
\t\t\"Monte Cristi\",
\t\t\"Monte Plata\",
\t\t\"Pedernales\",
\t\t\"Peravia\",
\t\t\"Puerto Plata\",
\t\t\"Salcedo\",
\t\t\"Saman\\u00e1\",
\t\t\"San Crist\\u00f3bal\",
\t\t\"San Pedro de Macor\\u00eds\",
\t\t\"S\\u00e1nchez Ram\\u00edrez\",
\t\t\"Santiago\",
\t\t\"Santiago Rodr\\u00edguez\",
\t\t\"Valverde\"
\t],
\t\"Algeria\": [
\t\t\"Adrar\",
\t\t\"Ain Defla\",
\t\t\"Ain Tmouchent\",
\t\t\"Alger\",
\t\t\"Annaba\",
\t\t\"Batna\",
\t\t\"Bechar\",
\t\t\"Bejaia\",
\t\t\"Biskra\",
\t\t\"Blida\",
\t\t\"Bordj Bou Arreridj\",
\t\t\"Bouira\",
\t\t\"Boumerdes\",
\t\t\"Chlef\",
\t\t\"Constantine\",
\t\t\"Djelfa\",
\t\t\"El Bayadh\",
\t\t\"El Oued\",
\t\t\"El Tarf\",
\t\t\"Ghardaia\",
\t\t\"Guelma\",
\t\t\"Illizi\",
\t\t\"Jijel\",
\t\t\"Khenchela\",
\t\t\"Laghouat\",
\t\t\"Mascara\",
\t\t\"Medea\",
\t\t\"Mila\",
\t\t\"Mostaganem\",
\t\t\"Msila\",
\t\t\"Naama\",
\t\t\"Oran\",
\t\t\"Ouargla\",
\t\t\"Oum el Bouaghi\",
\t\t\"Relizane\",
\t\t\"Saida\",
\t\t\"Setif\",
\t\t\"Sidi Bel Abbes\",
\t\t\"Skikda\",
\t\t\"Souk Ahras\",
\t\t\"Tamanghasset\",
\t\t\"Tebessa\",
\t\t\"Tiaret\",
\t\t\"Tindouf\",
\t\t\"Tipaza\",
\t\t\"Tissemsilt\",
\t\t\"Tizi Ouzou\",
\t\t\"Tlemcen\"
\t],
\t\"Ecuador\": [
\t\t\"Azuay\",
\t\t\"Bolivar\",
\t\t\"Canar\",
\t\t\"Carchi\",
\t\t\"Cotopaxi\",
\t\t\"Chimborazo\",
\t\t\"El Oro\",
\t\t\"Esmeraldas\",
\t\t\"Galapagos\",
\t\t\"Guayas\",
\t\t\"Imbabura\",
\t\t\"Loja\",
\t\t\"Los Rios\",
\t\t\"Manabi\",
\t\t\"Morona-Santiago\",
\t\t\"Napo\",
\t\t\"Orellana\",
\t\t\"Pastaza\",
\t\t\"Pichincha\",
\t\t\"Sucumbios\",
\t\t\"Tungurahua\",
\t\t\"Zamora-Chinchipe\"
\t],
\t\"Estonia\": [
\t\t\"Harjumsa\",
\t\t\"Hitumea\",
\t\t\"Ida-Virumsa\",
\t\t\"Jogevamsa\",
\t\t\"Jarvamsa\",
\t\t\"Lasnemsa\",
\t\t\"Laane-Virumaa\",
\t\t\"Polvamea\",
\t\t\"Parnumsa\",
\t\t\"Raplamsa\",
\t\t\"Saaremsa\",
\t\t\"Tartumsa\",
\t\t\"Valgamaa\",
\t\t\"Viljandimsa\",
\t\t\"Vorumaa\"
\t],
\t\"Egypt\": [
\t\t\"Ad Daqahllyah\",
\t\t\"Al Bahr al Ahmar\",
\t\t\"Al Buhayrah\",
\t\t\"Al Fayym\",
\t\t\"Al Gharbiyah\",
\t\t\"Al Iskandarlyah\",
\t\t\"Al Isma illyah\",
\t\t\"Al Jizah\",
\t\t\"Al Minuflyah\",
\t\t\"Al Minya\",
\t\t\"Al Qahirah\",
\t\t\"Al Qalyublyah\",
\t\t\"Al Wadi al Jadid\",
\t\t\"Ash Sharqiyah\",
\t\t\"As Suways\",
\t\t\"Aswan\",
\t\t\"Asyut\",
\t\t\"Bani Suwayf\",
\t\t\"Bur Sa'id\",
\t\t\"Dumyat\",
\t\t\"Janub Sina'\",
\t\t\"Kafr ash Shaykh\",
\t\t\"Matruh\",
\t\t\"Qina\",
\t\t\"Shamal Sina'\",
\t\t\"Suhaj\"
\t],
\t\"Eritrea\": [
\t\t\"Anseba\",
\t\t\"Debub\",
\t\t\"Debubawi Keyih Bahri [Debub-Keih-Bahri]\",
\t\t\"Gash-Barka\",
\t\t\"Maakel [Maekel]\",
\t\t\"Semenawi Keyih Bahri [Semien-Keih-Bahri]\"
\t],
\t\"Spain\": [
\t\t\"\\u00c1lava\",
\t\t\"Albacete\",
\t\t\"Alicante\",
\t\t\"Almer\\u00eda\",
\t\t\"Asturias\",
\t\t\"\\u00c1vila\",
\t\t\"Badajoz\",
\t\t\"Baleares\",
\t\t\"Barcelona\",
\t\t\"Burgos\",
\t\t\"C\\u00e1ceres\",
\t\t\"C\\u00e1diz\",
\t\t\"Cantabria\",
\t\t\"Castell\\u00f3n\",
\t\t\"Ciudad Real\",
\t\t\"Cuenca\",
\t\t\"C\\u00f3rdoba\",
\t\t\"Girona [Gerona]\",
\t\t\"Granada\",
\t\t\"Guadalajara\",
\t\t\"Guip\\u00fazcoa\",
\t\t\"Huelva\",
\t\t\"Huesca\",
\t\t\"Ja\\u00e9n\",
\t\t\"La Coru\\u00f1a\",
\t\t\"La Rioja\",
\t\t\"Las Palmas\",
\t\t\"Le\\u00f3n\",
\t\t\"Lleida [L\\u00e9rida]\",
\t\t\"Lugo\",
\t\t\"Madrid\",
\t\t\"M\\u00e1laga\",
\t\t\"Marbella\",
\t\t\"Murcia\",
\t\t\"Navarra\",
\t\t\"Ourense\",
\t\t\"Palencia\",
\t\t\"Pontevedra\",
\t\t\"Salamanca\",
\t\t\"Santa Cruz de Tenerife\",
\t\t\"Segovia\",
\t\t\"Sevilla\",
\t\t\"Soria\",
\t\t\"Tarragona\",
\t\t\"Teruel\",
\t\t\"Toledo\",
\t\t\"Valencia\",
\t\t\"Valladolid\",
\t\t\"Vizcaya\",
\t\t\"Zamora\",
\t\t\"Zaragoza\",
\t\t\"Ceuta\",
\t\t\"Melilla\"
\t],
\t\"Ethiopia\": [
\t\t\"Addis Ababa\",
\t\t\"Dire Dawa\",
\t\t\"Afar\",
\t\t\"Amara\",
\t\t\"Benshangul-Gumaz\",
\t\t\"Gambela Peoples\",
\t\t\"Harari People\",
\t\t\"Oromia\",
\t\t\"Somali\",
\t\t\"Southern Nations, Nationalities and Peoples\",
\t\t\"Tigrai\"
\t],
\t\"Fiji\": [
\t\t\"Northern\",
\t\t\"Western\",
\t\t\"Rotuma\"
\t],
\t\"Micronesia, Federated States of\": [
\t\t\"Chuuk\",
\t\t\"Kosrae\",
\t\t\"Pohnpei\",
\t\t\"Yap\"
\t],
\t\"Ghana\": [
\t\t\"Ashanti\",
\t\t\"Brong-Ahafo\",
\t\t\"Greater Accra\",
\t\t\"Upper East\",
\t\t\"Upper West\",
\t\t\"Volta\"
\t],
\t\"United Kingdom\": [
\t\t\"Aberdeen City\",
\t\t\"Aberdeenshire\",
\t\t\"Angus\",
\t\t\"Co Antrim\",
\t\t\"Argyll and Bute\",
\t\t\"Co Armagh\",
\t\t\"Bedfordshire\",
\t\t\"Gwent\",
\t\t\"Bristol, City of\",
\t\t\"Buckinghamshire\",
\t\t\"Cambridgeshire\",
\t\t\"Cheshire\",
\t\t\"Clackmannanshire\",
\t\t\"Cornwall\",
\t\t\"Cumbria\",
\t\t\"Derbyshire\",
\t\t\"Co Londonderry\",
\t\t\"Devon\",
\t\t\"Dorset\",
\t\t\"Co Down\",
\t\t\"Dumfries and Galloway\",
\t\t\"Dundee City\",
\t\t\"County Durham\",
\t\t\"East Ayrshire\",
\t\t\"East Dunbartonshire\",
\t\t\"East Lothian\",
\t\t\"East Renfrewshire\",
\t\t\"East Riding of Yorkshire\",
\t\t\"East Sussex\",
\t\t\"Edinburgh, City of\",
\t\t\"Na h-Eileanan Siar\",
\t\t\"Essex\",
\t\t\"Falkirk\",
\t\t\"Co Fermanagh\",
\t\t\"Fife\",
\t\t\"Glasgow City\",
\t\t\"Gloucestershire\",
\t\t\"Gwynedd\",
\t\t\"Hampshire\",
\t\t\"Herefordshire\",
\t\t\"Hertfordshire\",
\t\t\"Highland\",
\t\t\"Inverclyde\",
\t\t\"Isle of Wight\",
\t\t\"Kent\",
\t\t\"Lancashire\",
\t\t\"Leicestershire\",
\t\t\"Lincolnshire\",
\t\t\"Midlothian\",
\t\t\"Moray\",
\t\t\"Norfolk\",
\t\t\"North Ayrshire\",
\t\t\"North Lanarkshire\",
\t\t\"North Yorkshire\",
\t\t\"Northamptonshire\",
\t\t\"Northumberland\",
\t\t\"Nottinghamshire\",
\t\t\"Oldham\",
\t\t\"Omagh\",
\t\t\"Orkney Islands\",
\t\t\"Oxfordshire\",
\t\t\"Perth and Kinross\",
\t\t\"Powys\",
\t\t\"Renfrewshire\",
\t\t\"Rutland\",
\t\t\"Scottish Borders\",
\t\t\"Shetland Islands\",
\t\t\"Shropshire\",
\t\t\"Somerset\",
\t\t\"South Ayrshire\",
\t\t\"South Gloucestershire\",
\t\t\"South Lanarkshire\",
\t\t\"Staffordshire\",
\t\t\"Stirling\",
\t\t\"Suffolk\",
\t\t\"Surrey\",
\t\t\"Mid Glamorgan\",
\t\t\"Warwickshire\",
\t\t\"West Dunbartonshire\",
\t\t\"West Lothian\",
\t\t\"West Sussex\",
\t\t\"Wiltshire\",
\t\t\"Worcestershire\",
\t\t\"Tyne and Wear\",
\t\t\"Greater Manchester\",
\t\t\"Co Tyrone\",
\t\t\"West Yorkshire\",
\t\t\"South Yorkshire\",
\t\t\"Merseyside\",
\t\t\"Berkshire\",
\t\t\"West Midlands\",
\t\t\"West Glamorgan\",
\t\t\"Greater London\",
\t\t\"Clwyd\",
\t\t\"Dyfed\",
\t\t\"South Glamorgan\"
\t],
\t\"Gambia\": [
\t\t\"Banjul\",
\t\t\"Lower River\",
\t\t\"MacCarthy Island\",
\t\t\"North Bank\",
\t\t\"Upper River\"
\t],
\t\"Guinea\": [
\t\t\"Beyla\",
\t\t\"Boffa\",
\t\t\"Boke\",
\t\t\"Coyah\",
\t\t\"Dabola\",
\t\t\"Dalaba\",
\t\t\"Dinguiraye\",
\t\t\"Dubreka\",
\t\t\"Faranah\",
\t\t\"Forecariah\",
\t\t\"Fria\",
\t\t\"Gaoual\",
\t\t\"Guekedou\",
\t\t\"Kankan\",
\t\t\"Kerouane\",
\t\t\"Kindia\",
\t\t\"Kissidougou\",
\t\t\"Koubia\",
\t\t\"Koundara\",
\t\t\"Kouroussa\",
\t\t\"Labe\",
\t\t\"Lelouma\",
\t\t\"Lola\",
\t\t\"Macenta\",
\t\t\"Mali\",
\t\t\"Mamou\",
\t\t\"Mandiana\",
\t\t\"Nzerekore\",
\t\t\"Pita\",
\t\t\"Siguiri\",
\t\t\"Telimele\",
\t\t\"Tougue\",
\t\t\"Yomou\"
\t],
\t\"Equatorial Guinea\": [
\t\t\"Region Continental\",
\t\t\"Region Insular\",
\t\t\"Annobon\",
\t\t\"Bioko Norte\",
\t\t\"Bioko Sur\",
\t\t\"Centro Sur\",
\t\t\"Kie-Ntem\",
\t\t\"Litoral\",
\t\t\"Wele-Nzas\"
\t],
\t\"Greece\": [
\t\t\"Acha\\u00efa\",
\t\t\"Aitolia-Akarnania\",
\t\t\"Argolis\",
\t\t\"Arkadia\",
\t\t\"Arta\",
\t\t\"Attiki\",
\t\t\"Chalkidiki\",
\t\t\"Chania\",
\t\t\"Chios\",
\t\t\"Dodekanisos\",
\t\t\"Drama\",
\t\t\"Evros\",
\t\t\"Evrytania\",
\t\t\"Evvoia\",
\t\t\"Florina\",
\t\t\"Fokis\",
\t\t\"Fthiotis\",
\t\t\"Grevena\",
\t\t\"Ileia\",
\t\t\"Imathia\",
\t\t\"Ioannina\",
\t\t\"Irakleion\",
\t\t\"Karditsa\",
\t\t\"Kastoria\",
\t\t\"Kavalla\",
\t\t\"Kefallinia\",
\t\t\"Kerkyra\",
\t\t\"Kilkis\",
\t\t\"Korinthia\",
\t\t\"Kozani\",
\t\t\"Kyklades\",
\t\t\"Lakonia\",
\t\t\"Larisa\",
\t\t\"Lasithion\",
\t\t\"Lefkas\",
\t\t\"Lesvos\",
\t\t\"Magnisia\",
\t\t\"Messinia\",
\t\t\"Pella\",
\t\t\"Preveza\",
\t\t\"Rethymnon\",
\t\t\"Rodopi\",
\t\t\"Samos\",
\t\t\"Serrai\",
\t\t\"Thesprotia\",
\t\t\"Thessaloniki\",
\t\t\"Trikala\",
\t\t\"Voiotia\",
\t\t\"Xanthi\",
\t\t\"Zakynthos\",
\t\t\"Agio Oros\"
\t],
\t\"Guatemala\": [
\t\t\"Alta Verapez\",
\t\t\"Baja Verapez\",
\t\t\"Chimaltenango\",
\t\t\"Chiquimula\",
\t\t\"El Progreso\",
\t\t\"Escuintla\",
\t\t\"Guatemala\",
\t\t\"Huehuetenango\",
\t\t\"Izabal\",
\t\t\"Jalapa\",
\t\t\"Jutiapa\",
\t\t\"Peten\",
\t\t\"Quetzaltenango\",
\t\t\"Quiche\",
\t\t\"Reta.thuleu\",
\t\t\"Sacatepequez\",
\t\t\"San Marcos\",
\t\t\"Santa Rosa\",
\t\t\"Solol6\",
\t\t\"Suchitepequez\",
\t\t\"Totonicapan\",
\t\t\"Zacapa\"
\t],
\t\"Guinea-Bissau\": [
\t\t\"Bissau\",
\t\t\"Bafata\",
\t\t\"Biombo\",
\t\t\"Bolama\",
\t\t\"Cacheu\",
\t\t\"Gabu\",
\t\t\"Oio\",
\t\t\"Quloara\",
\t\t\"Tombali S\"
\t],
\t\"Guyana\": [
\t\t\"Barima-Waini\",
\t\t\"Cuyuni-Mazaruni\",
\t\t\"Demerara-Mahaica\",
\t\t\"East Berbice-Corentyne\",
\t\t\"Essequibo Islands-West Demerara\",
\t\t\"Mahaica-Berbice\",
\t\t\"Pomeroon-Supenaam\",
\t\t\"Potaro-Siparuni\",
\t\t\"Upper Demerara-Berbice\",
\t\t\"Upper Takutu-Upper Essequibo\"
\t],
\t\"Honduras\": [
\t\t\"Atlantida\",
\t\t\"Colon\",
\t\t\"Comayagua\",
\t\t\"Copan\",
\t\t\"Cortes\",
\t\t\"Choluteca\",
\t\t\"El Paraiso\",
\t\t\"Francisco Morazan\",
\t\t\"Gracias a Dios\",
\t\t\"Intibuca\",
\t\t\"Islas de la Bahia\",
\t\t\"Lempira\",
\t\t\"Ocotepeque\",
\t\t\"Olancho\",
\t\t\"Santa Barbara\",
\t\t\"Valle\",
\t\t\"Yoro\"
\t],
\t\"Croatia\": [
\t\t\"Bjelovarsko-bilogorska zupanija\",
\t\t\"Brodsko-posavska zupanija\",
\t\t\"Dubrovacko-neretvanska zupanija\",
\t\t\"Istarska zupanija\",
\t\t\"Karlovacka zupanija\",
\t\t\"Koprivnickco-krizevacka zupanija\",
\t\t\"Krapinako-zagorska zupanija\",
\t\t\"Licko-senjska zupanija\",
\t\t\"Medimurska zupanija\",
\t\t\"Osjecko-baranjska zupanija\",
\t\t\"Pozesko-slavonska zupanija\",
\t\t\"Primorsko-goranska zupanija\",
\t\t\"Sisacko-moelavacka Iupanija\",
\t\t\"Splitako-dalmatinska zupanija\",
\t\t\"Sibenako-kninska zupanija\",
\t\t\"Varaidinska zupanija\",
\t\t\"VirovitiEko-podravska zupanija\",
\t\t\"VuRovarako-srijemska zupanija\",
\t\t\"Zadaraka\",
\t\t\"Zagrebacka zupanija\"
\t],
\t\"Hungary\": [
\t\t\"Budapest\",
\t\t\"B\\u00e1cs-Kiskun\",
\t\t\"Baranya\",
\t\t\"B\\u00e9k\\u00e9s\",
\t\t\"Borsod-Aba\\u00faj-Zempl\\u00e9n\",
\t\t\"Csongr\\u00e1d\",
\t\t\"Fej\\u00e9r\",
\t\t\"Gy\\u0151r-Moson-Sopron\",
\t\t\"Hajdu-Bihar\",
\t\t\"Heves\",
\t\t\"J\\u00e1sz-Nagykun-Szolnok\",
\t\t\"Kom\\u00e1rom-Esztergom\",
\t\t\"Nogr\\u00e1d\",
\t\t\"Pest\",
\t\t\"Somogy\",
\t\t\"Szabolcs-Szatm\\u00e1r-Bereg\",
\t\t\"Tolna\",
\t\t\"Vas\",
\t\t\"Veszpr\\u00e9m\",
\t\t\"Zala\",
\t\t\"B\\u00e9k\\u00e9scsaba\",
\t\t\"Debrecen\",
\t\t\"Duna\\u00fajv\\u00e1ros\",
\t\t\"Eger\",
\t\t\"Gy\\u0151r\",
\t\t\"H\\u00f3dmez\\u0151v\\u00e1s\\u00e1rhely\",
\t\t\"Kaposv\\u00e1r\",
\t\t\"Kecskem\\u00e9t\",
\t\t\"Miskolc\",
\t\t\"Nagykanizsa\",
\t\t\"Nyiregyh\\u00e1za\",
\t\t\"P\\u00e9cs\",
\t\t\"Salg\\u00f3tarj\\u00e1n\",
\t\t\"Sopron\",
\t\t\"Szeged\",
\t\t\"Sz\\u00e9kesfeh\\u00e9rv\\u00e1r\",
\t\t\"Szeksz\\u00e1rd\",
\t\t\"Szolnok\",
\t\t\"Szombathely\",
\t\t\"Tatab\\u00e1nya\",
\t\t\"Zalaegerszeg\"
\t],
\t\"Indonesia\": [
\t\t\"Bali\",
\t\t\"Bangka Belitung\",
\t\t\"Banten\",
\t\t\"Bengkulu\",
\t\t\"Gorontalo\",
\t\t\"Irian Jaya\",
\t\t\"Jambi\",
\t\t\"Jawa Barat\",
\t\t\"Jawa Tengah\",
\t\t\"Jawa Timur\",
\t\t\"Kalimantan Barat\",
\t\t\"Kalimantan Timur\",
\t\t\"Kalimantan Selatan\",
\t\t\"Kepulauan Riau\",
\t\t\"Lampung\",
\t\t\"Maluku\",
\t\t\"Maluku Utara\",
\t\t\"Nusa Tenggara Barat\",
\t\t\"Nusa Tenggara Timur\",
\t\t\"Papua\",
\t\t\"Riau\",
\t\t\"Sulawesi Selatan\",
\t\t\"Sulawesi Tengah\",
\t\t\"Sulawesi Tenggara\",
\t\t\"Sulawesi Utara\",
\t\t\"Sumatra Barat\",
\t\t\"Sumatra Selatan\",
\t\t\"Sumatera Utara\",
\t\t\"Jakarta Raya\",
\t\t\"Aceh\",
\t\t\"Yogyakarta\"
\t],
\t\"Ireland\": [
\t\t\"Cork\",
\t\t\"Clare\",
\t\t\"Cavan\",
\t\t\"Carlow\",
\t\t\"Dublin\",
\t\t\"Donegal\",
\t\t\"Galway\",
\t\t\"Kildare\",
\t\t\"Kilkenny\",
\t\t\"Kerry\",
\t\t\"Longford\",
\t\t\"Louth\",
\t\t\"Limerick\",
\t\t\"Leitrim\",
\t\t\"Laois\",
\t\t\"Meath\",
\t\t\"Monaghan\",
\t\t\"Mayo\",
\t\t\"Offaly\",
\t\t\"Roscommon\",
\t\t\"Sligo\",
\t\t\"Tipperary\",
\t\t\"Waterford\",
\t\t\"Westmeath\",
\t\t\"Wicklow\",
\t\t\"Wexford\"
\t],
\t\"Israel\": [
\t\t\"HaDarom\",
\t\t\"HaMerkaz\",
\t\t\"HaZafon\",
\t\t\"Haifa\",
\t\t\"Tel-Aviv\"
\t],
\t\"Palestinian Territory, Occupied\": [
\t\t\"Jerusalem\",
\t\t\"Gaza\",
\t\t\"Jenin\",
\t\t\"Tubas\",
\t\t\"Tulkarm\",
\t\t\"Nablus\",
\t\t\"Qalqilya\",
\t\t\"Salfit\",
\t\t\"Ramallah and Al-Bireh\",
\t\t\"Jericho\",
\t\t\"Bethlehem\",
\t\t\"Hebron\",
\t\t\"North Gaza\",
\t\t\"Deir el-Balah\",
\t\t\"Khan Yunis\",
\t\t\"Rafah\"
\t],
\t\"Iraq\": [
\t\t\"Al Anbar\",
\t\t\"Al Ba, rah\",
\t\t\"Al Muthanna\",
\t\t\"Al Qadisiyah\",
\t\t\"An Najef\",
\t\t\"Arbil\",
\t\t\"As Sulaymaniyah\",
\t\t\"At Ta'mim\",
\t\t\"Babil\",
\t\t\"Baghdad\",
\t\t\"Dahuk\",
\t\t\"Dhi Qar\",
\t\t\"Diyala\",
\t\t\"Karbala'\",
\t\t\"Maysan\",
\t\t\"Ninawa\",
\t\t\"Salah ad Din\",
\t\t\"Wasit\"
\t],
\t\"Iran, Islamic Republic of\": [
\t\t\"Ardabil\",
\t\t\"Azarbayjan-e Gharbi\",
\t\t\"Azarbayjan-e Sharqi\",
\t\t\"Bushehr\",
\t\t\"Chahar Mahall va Bakhtiari\",
\t\t\"Esfahan\",
\t\t\"Fars\",
\t\t\"Gilan\",
\t\t\"Golestan\",
\t\t\"Hamadan\",
\t\t\"Hormozgan\",
\t\t\"Iiam\",
\t\t\"Kerman\",
\t\t\"Kermanshah\",
\t\t\"Khorasan\",
\t\t\"Khuzestan\",
\t\t\"Kohjiluyeh va Buyer Ahmad\",
\t\t\"Kordestan\",
\t\t\"Lorestan\",
\t\t\"Markazi\",
\t\t\"Mazandaran\",
\t\t\"Qazvin\",
\t\t\"Qom\",
\t\t\"Semnan\",
\t\t\"Sistan va Baluchestan\",
\t\t\"Tehran\",
\t\t\"Yazd\",
\t\t\"Zanjan\"
\t],
\t\"Iceland\": [
\t\t\"Austurland\",
\t\t\"Hofuoborgarsvaeoi utan Reykjavikur\",
\t\t\"Norourland eystra\",
\t\t\"Norourland vestra\",
\t\t\"Reykjavik\",
\t\t\"Suourland\",
\t\t\"Suournes\",
\t\t\"Vestfirolr\",
\t\t\"Vesturland\"
\t],
\t\"Italy\": [
\t\t\"Agrigento\",
\t\t\"Alessandria\",
\t\t\"Ancona\",
\t\t\"Aosta\",
\t\t\"Arezzo\",
\t\t\"Ascoli Piceno\",
\t\t\"Asti\",
\t\t\"Avellino\",
\t\t\"Bari\",
\t\t\"Belluno\",
\t\t\"Benevento\",
\t\t\"Bergamo\",
\t\t\"Biella\",
\t\t\"Bologna\",
\t\t\"Bolzano\",
\t\t\"Brescia\",
\t\t\"Brindisi\",
\t\t\"Cagliari\",
\t\t\"Caltanissetta\",
\t\t\"Campobasso\",
\t\t\"Caserta\",
\t\t\"Catania\",
\t\t\"Catanzaro\",
\t\t\"Chieti\",
\t\t\"Como\",
\t\t\"Cosenza\",
\t\t\"Cremona\",
\t\t\"Crotone\",
\t\t\"Cuneo\",
\t\t\"Enna\",
\t\t\"Ferrara\",
\t\t\"Firenze\",
\t\t\"Foggia\",
\t\t\"Forl\\u00ec-Cesena\",
\t\t\"Frosinone\",
\t\t\"Genova\",
\t\t\"Gorizia\",
\t\t\"Grosseto\",
\t\t\"Imperia\",
\t\t\"Isernia\",
\t\t\"L'Aquila\",
\t\t\"La Spezia\",
\t\t\"Latina\",
\t\t\"Lecce\",
\t\t\"Lecco\",
\t\t\"Livorno\",
\t\t\"Lodi\",
\t\t\"Lucca\",
\t\t\"Macerata\",
\t\t\"Mantova\",
\t\t\"Massa-Carrara\",
\t\t\"Matera\",
\t\t\"Messina\",
\t\t\"Milano\",
\t\t\"Modena\",
\t\t\"Napoli\",
\t\t\"Novara\",
\t\t\"Nuoro\",
\t\t\"Oristano\",
\t\t\"Padova\",
\t\t\"Palermo\",
\t\t\"Parma\",
\t\t\"Pavia\",
\t\t\"Perugia\",
\t\t\"Pesaro e Urbino\",
\t\t\"Pescara\",
\t\t\"Piacenza\",
\t\t\"Pisa\",
\t\t\"Pistoia\",
\t\t\"Pordenone\",
\t\t\"Potenza\",
\t\t\"Prato\",
\t\t\"Ragusa\",
\t\t\"Ravenna\",
\t\t\"Reggio Calabria\",
\t\t\"Reggio Emilia\",
\t\t\"Rieti\",
\t\t\"Rimini\",
\t\t\"Roma\",
\t\t\"Rovigo\",
\t\t\"Salerno\",
\t\t\"Sassari\",
\t\t\"Savona\",
\t\t\"Siena\",
\t\t\"Siracusa\",
\t\t\"Sondrio\",
\t\t\"Taranto\",
\t\t\"Teramo\",
\t\t\"Terni\",
\t\t\"Torino\",
\t\t\"Trapani\",
\t\t\"Trento\",
\t\t\"Treviso\",
\t\t\"Trieste\",
\t\t\"Udine\",
\t\t\"Varese\",
\t\t\"Venezia\",
\t\t\"Verbano-Cusio-Ossola\",
\t\t\"Vercelli\",
\t\t\"Verona\",
\t\t\"Vibo Valentia\",
\t\t\"Vicenza\",
\t\t\"Viterbo\",
\t\t\"Carbonia-Iglesias\",
\t\t\"Olbia-Tempio\",
\t\t\"Medio Campidano\",
\t\t\"Ogliastra\",
\t\t\"Barletta-Andria-Trani\",
\t\t\"Fermo\",
\t\t\"Monza e Brianza\"
\t],
\t\"Japan\": [
\t\t\"Aichi\",
\t\t\"Akita\",
\t\t\"Aomori\",
\t\t\"Chiba\",
\t\t\"Ehime\",
\t\t\"Fukui\",
\t\t\"Fukuoka\",
\t\t\"Fukushima\",
\t\t\"Gifu\",
\t\t\"Gunma\",
\t\t\"Hiroshima\",
\t\t\"Hokkaido\",
\t\t\"Hyogo\",
\t\t\"Ibaraki\",
\t\t\"Ishikawa\",
\t\t\"Iwate\",
\t\t\"Kagawa\",
\t\t\"Kagoshima\",
\t\t\"Kanagawa\",
\t\t\"Kochi\",
\t\t\"Kumamoto\",
\t\t\"Kyoto\",
\t\t\"Mie\",
\t\t\"Miyagi\",
\t\t\"Miyazaki\",
\t\t\"Nagano\",
\t\t\"Nagasaki\",
\t\t\"Nara\",
\t\t\"Niigata\",
\t\t\"Oita\",
\t\t\"Okayama\",
\t\t\"Okinawa\",
\t\t\"Osaka\",
\t\t\"Saga\",
\t\t\"Saitama\",
\t\t\"Shiga\",
\t\t\"Shimane\",
\t\t\"Shizuoka\",
\t\t\"Tochigi\",
\t\t\"Tokushima\",
\t\t\"Tokyo\",
\t\t\"Tottori\",
\t\t\"Toyama\",
\t\t\"Wakayama\",
\t\t\"Yamagata\",
\t\t\"Yamaguchi\",
\t\t\"Yamanashi\"
\t],
\t\"Jamaica\": [
\t\t\"Clarendon\",
\t\t\"Hanover\",
\t\t\"Kingston\",
\t\t\"Portland\",
\t\t\"Saint Andrew\",
\t\t\"Saint Ann\",
\t\t\"Saint Catherine\",
\t\t\"Saint Elizabeth\",
\t\t\"Saint James\",
\t\t\"Saint Mary\",
\t\t\"Saint Thomas\",
\t\t\"Trelawny\",
\t\t\"Westmoreland\",
\t\t\"Manchester\"
\t],
\t\"Jordan\": [
\t\t\"Ajln\",
\t\t\"Al 'Aqaba\",
\t\t\"Al Balqa'\",
\t\t\"Al Karak\",
\t\t\"Al Mafraq\",
\t\t\"Amman\",
\t\t\"At Tafilah\",
\t\t\"Az Zarga\",
\t\t\"Irbid\",
\t\t\"Jarash\",
\t\t\"Ma'an\",
\t\t\"Madaba\"
\t],
\t\"Kenya\": [
\t\t\"Baringo County\",
\t\t\"Bomet County\",
\t\t\"Bungoma County\",
\t\t\"Busia County\",
\t\t\"Elgeyo-Marakwet County\",
\t\t\"Embu County\",
\t\t\"Garissa County\",
\t\t\"Homa Bay County\",
\t\t\"Isiolo County\",
\t\t\"Kajiado County\",
\t\t\"Kakamega County\",
\t\t\"Kericho County\",
\t\t\"Kiambu County\",
\t\t\"Kilifi County\",
\t\t\"Kirinyaga County\",
\t\t\"Kisii County\",
\t\t\"Kisumu County\",
\t\t\"Kitui County\",
\t\t\"Kwale County\",
\t\t\"Laikipia County\",
\t\t\"Lamu County\",
\t\t\"Machakos County\",
\t\t\"Makueni County\",
\t\t\"Mandera County\",
\t\t\"Marsabit County\",
\t\t\"Meru County\",
\t\t\"Migori County\",
\t\t\"Mombasa County\",
\t\t\"Murang'a County\",
\t\t\"Nairobi City County\",
\t\t\"Nakuru County\",
\t\t\"Nandi County\",
\t\t\"Narok County\",
\t\t\"Nyamira County\",
\t\t\"Nyandarua County\",
\t\t\"Nyeri County\",
\t\t\"Samburu County\",
\t\t\"Siaya County\",
\t\t\"Taita–Taveta County\",
\t\t\"Tana River County\",
\t\t\"Tharaka-Nithi County\",
\t\t\"Trans-Nzoia County\",
\t\t\"Turkana County\",
\t\t\"Uasin Gishu County\",
\t\t\"Vihiga County\",
\t\t\"Wajir County\",
\t\t\"West Pokot County\"
\t],
\t\"Kyrgyzstan\": [
\t\t\"Bishkek\",
\t\t\"Batken\",
\t\t\"Chu\",
\t\t\"Jalal-Abad\",
\t\t\"Naryn\",
\t\t\"Osh\",
\t\t\"Talas\",
\t\t\"Ysyk-Kol\"
\t],
\t\"Cambodia\": [
\t\t\"Krong Kaeb\",
\t\t\"Krong Pailin\",
\t\t\"Xrong Preah Sihanouk\",
\t\t\"Phnom Penh\",
\t\t\"Baat Dambang\",
\t\t\"Banteay Mean Chey\",
\t\t\"Rampong Chaam\",
\t\t\"Kampong Chhnang\",
\t\t\"Kampong Spueu\",
\t\t\"Kampong Thum\",
\t\t\"Kampot\",
\t\t\"Kandaal\",
\t\t\"Kach Kong\",
\t\t\"Krachoh\",
\t\t\"Mondol Kiri\",
\t\t\"Otdar Mean Chey\",
\t\t\"Pousaat\",
\t\t\"Preah Vihear\",
\t\t\"Prey Veaeng\",
\t\t\"Rotanak Kiri\",
\t\t\"Siem Reab\",
\t\t\"Stueng Traeng\",
\t\t\"Svaay Rieng\",
\t\t\"Taakaev\"
\t],
\t\"Kiribati\": [
\t\t\"Gilbert Islands\",
\t\t\"Line Islands\",
\t\t\"Phoenix Islands\"
\t],
\t\"Comoros\": [
\t\t\"Anjouan Ndzouani\",
\t\t\"Grande Comore Ngazidja\",
\t\t\"Moheli Moili\"
\t],
\t\"Korea, Democratic People's Republic of\": [
\t\t\"Kaesong-si\",
\t\t\"Nampo-si\",
\t\t\"Pyongyang-ai\",
\t\t\"Chagang-do\",
\t\t\"Hamgyongbuk-do\",
\t\t\"Hamgyongnam-do\",
\t\t\"Hwanghaebuk-do\",
\t\t\"Hwanghaenam-do\",
\t\t\"Kangwon-do\",
\t\t\"Pyonganbuk-do\",
\t\t\"Pyongannam-do\",
\t\t\"Yanggang-do\",
\t\t\"Najin Sonbong-si\"
\t],
\t\"Korea, Republic of\": [
\t\t\"Seoul Teugbyeolsi\",
\t\t\"Busan Gwang'yeogsi\",
\t\t\"Daegu Gwang'yeogsi\",
\t\t\"Daejeon Gwang'yeogsi\",
\t\t\"Gwangju Gwang'yeogsi\",
\t\t\"Incheon Gwang'yeogsi\",
\t\t\"Ulsan Gwang'yeogsi\",
\t\t\"Chungcheongbugdo\",
\t\t\"Chungcheongnamdo\",
\t\t\"Gang'weondo\",
\t\t\"Gyeonggido\",
\t\t\"Gyeongsangbugdo\",
\t\t\"Gyeongsangnamdo\",
\t\t\"Jejudo\",
\t\t\"Jeonrabugdo\",
\t\t\"Jeonranamdo\"
\t],
\t\"Kosovo\": [
\t\t\"Ferizaj\",
\t\t\"Gjakova\",
\t\t\"Gjilan\",
\t\t\"Mitrovica\",
\t\t\"Peja/Pec\",
\t\t\"Pristina\",
\t\t\"Prizren\"
\t],
\t\"Kuwait\": [
\t\t\"Al Ahmadi\",
\t\t\"Al Farwanlyah\",
\t\t\"Al Jahrah\",
\t\t\"Al Kuwayt\",
\t\t\"Hawalli\"
\t],
\t\"Kazakhstan\": [
\t\t\"Almaty\",
\t\t\"Astana\",
\t\t\"Almaty oblysy\",
\t\t\"Aqmola oblysy\",
\t\t\"Aqtobe oblysy\",
\t\t\"Atyrau oblyfiy\",
\t\t\"Batys Quzaqstan oblysy\",
\t\t\"Mangghystau oblysy\",
\t\t\"Ongtustik Quzaqstan oblysy\",
\t\t\"Pavlodar oblysy\",
\t\t\"Qaraghandy oblysy\",
\t\t\"Qostanay oblysy\",
\t\t\"Qyzylorda oblysy\",
\t\t\"Shyghys Quzaqstan oblysy\",
\t\t\"Soltustik Quzaqstan oblysy\",
\t\t\"Zhambyl oblysy Zhambylskaya oblast'\"
\t],
\t\"Lao People's Democratic Republic\": [
\t\t\"Vientiane\",
\t\t\"Attapu\",
\t\t\"Bokeo\",
\t\t\"Bolikhamxai\",
\t\t\"Champasak\",
\t\t\"Houaphan\",
\t\t\"Khammouan\",
\t\t\"Louang Namtha\",
\t\t\"Louangphabang\",
\t\t\"Oudomxai\",
\t\t\"Phongsali\",
\t\t\"Salavan\",
\t\t\"Savannakhet\",
\t\t\"Xaignabouli\",
\t\t\"Xiasomboun\",
\t\t\"Xekong\",
\t\t\"Xiangkhoang\"
\t],
\t\"Lebanon\": [
\t\t\"Beirout\",
\t\t\"El Begsa\",
\t\t\"Jabal Loubnane\",
\t\t\"Loubnane ech Chemali\",
\t\t\"Loubnane ej Jnoubi\",
\t\t\"Nabatiye\"
\t],
\t\"Sri Lanka\": [
\t\t\"Ampara\",
\t\t\"Anuradhapura\",
\t\t\"Badulla\",
\t\t\"Batticaloa\",
\t\t\"Colombo\",
\t\t\"Galle\",
\t\t\"Gampaha\",
\t\t\"Hambantota\",
\t\t\"Jaffna\",
\t\t\"Kalutara\",
\t\t\"Kandy\",
\t\t\"Kegalla\",
\t\t\"Kilinochchi\",
\t\t\"Kurunegala\",
\t\t\"Mannar\",
\t\t\"Matale\",
\t\t\"Matara\",
\t\t\"Monaragala\",
\t\t\"Mullaittivu\",
\t\t\"Nuwara Eliya\",
\t\t\"Polonnaruwa\",
\t\t\"Puttalum\",
\t\t\"Ratnapura\",
\t\t\"Trincomalee\",
\t\t\"VavunLya\"
\t],
\t\"Lesotho\": [
\t\t\"Berea\",
\t\t\"Butha-Buthe\",
\t\t\"Leribe\",
\t\t\"Mafeteng\",
\t\t\"Maseru\",
\t\t\"Mohale's Hoek\",
\t\t\"Mokhotlong\",
\t\t\"Qacha's Nek\",
\t\t\"Quthing\",
\t\t\"Thaba-Tseka\"
\t],
\t\"Lithuania\": [
\t\t\"Alytaus Apskritis\",
\t\t\"Kauno Apskritis\",
\t\t\"Klaipedos Apskritis\",
\t\t\"Marijampoles Apskritis\",
\t\t\"Panevezio Apskritis\",
\t\t\"Sisuliu Apskritis\",
\t\t\"Taurages Apskritis\",
\t\t\"Telsiu Apskritis\",
\t\t\"Utenos Apskritis\",
\t\t\"Vilniaus Apskritis\"
\t],
\t\"Luxembourg\": [
\t\t\"Diekirch\",
\t\t\"GreveNmacher\"
\t],
\t\"Latvia\": [
\t\t\"Aizkraukles Apripkis\",
\t\t\"Alkanes Apripkis\",
\t\t\"Balvu Apripkis\",
\t\t\"Bauskas Apripkis\",
\t\t\"Cesu Aprikis\",
\t\t\"Daugavpile Apripkis\",
\t\t\"Dobeles Apripkis\",
\t\t\"Gulbenes Aprlpkis\",
\t\t\"Jelgavas Apripkis\",
\t\t\"Jekabpils Apripkis\",
\t\t\"Kraslavas Apripkis\",
\t\t\"Kuldlgas Apripkis\",
\t\t\"Limbazu Apripkis\",
\t\t\"Liepajas Apripkis\",
\t\t\"Ludzas Apripkis\",
\t\t\"Madonas Apripkis\",
\t\t\"Ogres Apripkis\",
\t\t\"Preilu Apripkis\",
\t\t\"Rezaknes Apripkis\",
\t\t\"Rigas Apripkis\",
\t\t\"Saldus Apripkis\",
\t\t\"Talsu Apripkis\",
\t\t\"Tukuma Apriplcis\",
\t\t\"Valkas Apripkis\",
\t\t\"Valmieras Apripkis\",
\t\t\"Ventspils Apripkis\",
\t\t\"Daugavpils\",
\t\t\"Jelgava\",
\t\t\"Jurmala\",
\t\t\"Liepaja\",
\t\t\"Rezekne\",
\t\t\"Riga\",
\t\t\"Ventspils\"
\t],
\t\"Libyan Arab Jamahiriya\": [
\t\t\"Ajd\\u0101biy\\u0101\",
\t\t\"Al Bu\\u0163n\\u0101n\",
\t\t\"Al Hiz\\u0101m al Akhdar\",
\t\t\"Al Jabal al Akhdar\",
\t\t\"Al Jif\\u0101rah\",
\t\t\"Al Jufrah\",
\t\t\"Al Kufrah\",
\t\t\"Al Marj\",
\t\t\"Al Marqab\",
\t\t\"Al Qa\\u0163r\\u016bn\",
\t\t\"Al Qubbah\",
\t\t\"Al W\\u0101hah\",
\t\t\"An Nuqa\\u0163 al Khams\",
\t\t\"Ash Sh\\u0101\\u0163i'\",
\t\t\"Az Z\\u0101wiyah\",
\t\t\"Bangh\\u0101z\\u012b\",
\t\t\"Ban\\u012b Wal\\u012bd\",
\t\t\"Darnah\",
\t\t\"Ghad\\u0101mis\",
\t\t\"Ghary\\u0101n\",
\t\t\"Gh\\u0101t\",
\t\t\"Jaghb\\u016bb\",
\t\t\"Mi\\u015fr\\u0101tah\",
\t\t\"Mizdah\",
\t\t\"Murzuq\",
\t\t\"N\\u0101l\\u016bt\",
\t\t\"Sabh\\u0101\",
\t\t\"\\u015eabr\\u0101tah \\u015eurm\\u0101n\",
\t\t\"Surt\",
\t\t\"T\\u0101j\\u016br\\u0101' wa an Naw\\u0101h\\u012b al Arb\\u0101h\",
\t\t\"\\u0162ar\\u0101bulus\",
\t\t\"Tarh\\u016bnah-Masall\\u0101tah\",
\t\t\"W\\u0101d\\u012b al hay\\u0101t\",
\t\t\"Yafran-J\\u0101d\\u016b\"
\t],
\t\"Liechtenstein\": [
\t\t\"Balzers\",
\t\t\"Eschen\",
\t\t\"Gamprin\",
\t\t\"Mauren\",
\t\t\"Planken\",
\t\t\"Ruggell\",
\t\t\"Schaan\",
\t\t\"Schellenberg\",
\t\t\"Triesen\",
\t\t\"Triesenberg\",
\t\t\"Vaduz\"
\t],
\t\"Morocco\": [
\t\t\"Agadir\",
\t\t\"A\\u00eft Baha\",
\t\t\"A\\u00eft Melloul\",
\t\t\"Al Haouz\",
\t\t\"Al Hoce\\u00efma\",
\t\t\"Assa-Zag\",
\t\t\"Azilal\",
\t\t\"Beni Mellal\",
\t\t\"Ben Sllmane\",
\t\t\"Berkane\",
\t\t\"Boujdour\",
\t\t\"Boulemane\",
\t\t\"Casablanca  [Dar el Be\\u00efda]\",
\t\t\"Chefchaouene\",
\t\t\"Chichaoua\",
\t\t\"El Hajeb\",
\t\t\"El Jadida\",
\t\t\"Errachidia\",
\t\t\"Essaouira\",
\t\t\"Es Smara\",
\t\t\"F\\u00e8s\",
\t\t\"Figuig\",
\t\t\"Guelmim\",
\t\t\"Ifrane\",
\t\t\"Jerada\",
\t\t\"Kelaat Sraghna\",
\t\t\"K\\u00e9nitra\",
\t\t\"Khemisaet\",
\t\t\"Khenifra\",
\t\t\"Khouribga\",
\t\t\"La\\u00e2youne (EH)\",
\t\t\"Larache\",
\t\t\"Marrakech\",
\t\t\"Mekns\\u00e8s\",
\t\t\"Nador\",
\t\t\"Ouarzazate\",
\t\t\"Oued ed Dahab (EH)\",
\t\t\"Oujda\",
\t\t\"Rabat-Sal\\u00e9\",
\t\t\"Safi\",
\t\t\"Sefrou\",
\t\t\"Settat\",
\t\t\"Sidl Kacem\",
\t\t\"Tanger\",
\t\t\"Tan-Tan\",
\t\t\"Taounate\",
\t\t\"Taroudannt\",
\t\t\"Tata\",
\t\t\"Taza\",
\t\t\"T\\u00e9touan\",
\t\t\"Tiznit\"
\t],
\t\"Moldova\": [
\t\t\"Gagauzia, Unitate Teritoriala Autonoma\",
\t\t\"Chisinau\",
\t\t\"Stinga Nistrului, unitatea teritoriala din\",
\t\t\"Balti\",
\t\t\"Cahul\",
\t\t\"Edinet\",
\t\t\"Lapusna\",
\t\t\"Orhei\",
\t\t\"Soroca\",
\t\t\"Taraclia\",
\t\t\"Tighina [Bender]\",
\t\t\"Ungheni\"
\t],
\t\"Madagascar\": [
\t\t\"Antananarivo\",
\t\t\"Antsiranana\",
\t\t\"Fianarantsoa\",
\t\t\"Mahajanga\",
\t\t\"Toamasina\",
\t\t\"Toliara\"
\t],
\t\"Marshall Islands\": [
\t\t\"Ailinglapalap\",
\t\t\"Ailuk\",
\t\t\"Arno\",
\t\t\"Aur\",
\t\t\"Ebon\",
\t\t\"Eniwetok\",
\t\t\"Jaluit\",
\t\t\"Kili\",
\t\t\"Kwajalein\",
\t\t\"Lae\",
\t\t\"Lib\",
\t\t\"Likiep\",
\t\t\"Majuro\",
\t\t\"Maloelap\",
\t\t\"Mejit\",
\t\t\"Mili\",
\t\t\"Namorik\",
\t\t\"Namu\",
\t\t\"Rongelap\",
\t\t\"Ujae\",
\t\t\"Ujelang\",
\t\t\"Utirik\",
\t\t\"Wotho\",
\t\t\"Wotje\"
\t],
\t\"Mali\": [
\t\t\"Bamako\",
\t\t\"Gao\",
\t\t\"Kayes\",
\t\t\"Kidal\",
\t\t\"Xoulikoro\",
\t\t\"Mopti\",
\t\t\"S69ou\",
\t\t\"Sikasso\",
\t\t\"Tombouctou\"
\t],
\t\"Myanmar\": [
\t\t\"Ayeyarwady\",
\t\t\"Bago\",
\t\t\"Magway\",
\t\t\"Mandalay\",
\t\t\"Sagaing\",
\t\t\"Tanintharyi\",
\t\t\"Yangon\",
\t\t\"Chin\",
\t\t\"Kachin\",
\t\t\"Kayah\",
\t\t\"Kayin\",
\t\t\"Mon\",
\t\t\"Rakhine\",
\t\t\"Shan\"
\t],
\t\"Mongolia\": [
\t\t\"Ulaanbaatar\",
\t\t\"Arhangay\",
\t\t\"Bayanhongor\",
\t\t\"Bayan-Olgiy\",
\t\t\"Bulgan\",
\t\t\"Darhan uul\",
\t\t\"Dornod\",
\t\t\"Dornogov\",
\t\t\"DundgovL\",
\t\t\"Dzavhan\",
\t\t\"Govi-Altay\",
\t\t\"Govi-Smber\",
\t\t\"Hentiy\",
\t\t\"Hovd\",
\t\t\"Hovsgol\",
\t\t\"Omnogovi\",
\t\t\"Orhon\",
\t\t\"Ovorhangay\",
\t\t\"Selenge\",
\t\t\"Shbaatar\",
\t\t\"Tov\",
\t\t\"Uvs\"
\t],
\t\"Mauritania\": [
\t\t\"Nouakchott\",
\t\t\"Assaba\",
\t\t\"Brakna\",
\t\t\"Dakhlet Nouadhibou\",
\t\t\"Gorgol\",
\t\t\"Guidimaka\",
\t\t\"Hodh ech Chargui\",
\t\t\"Hodh el Charbi\",
\t\t\"Inchiri\",
\t\t\"Tagant\",
\t\t\"Tiris Zemmour\",
\t\t\"Trarza\"
\t],
\t\"Mauritius\": [
\t\t\"Beau Bassin-Rose Hill\",
\t\t\"Curepipe\",
\t\t\"Port Louis\",
\t\t\"Quatre Bornes\",
\t\t\"Vacosa-Phoenix\",
\t\t\"Black River\",
\t\t\"Flacq\",
\t\t\"Grand Port\",
\t\t\"Moka\",
\t\t\"Pamplemousses\",
\t\t\"Plaines Wilhems\",
\t\t\"Riviere du Rempart\",
\t\t\"Savanne\",
\t\t\"Agalega Islands\",
\t\t\"Cargados Carajos Shoals\",
\t\t\"Rodrigues Island\"
\t],
\t\"Maldives\": [
\t\t\"Male\",
\t\t\"Alif\",
\t\t\"Baa\",
\t\t\"Dhaalu\",
\t\t\"Faafu\",
\t\t\"Gaaf Alif\",
\t\t\"Gaefu Dhaalu\",
\t\t\"Gnaviyani\",
\t\t\"Haa Alif\",
\t\t\"Haa Dhaalu\",
\t\t\"Kaafu\",
\t\t\"Laamu\",
\t\t\"Lhaviyani\",
\t\t\"Meemu\",
\t\t\"Noonu\",
\t\t\"Raa\",
\t\t\"Seenu\",
\t\t\"Shaviyani\",
\t\t\"Thaa\",
\t\t\"Vaavu\"
\t],
\t\"Malawi\": [
\t\t\"Balaka\",
\t\t\"Blantyre\",
\t\t\"Chikwawa\",
\t\t\"Chiradzulu\",
\t\t\"Chitipa\",
\t\t\"Dedza\",
\t\t\"Dowa\",
\t\t\"Karonga\",
\t\t\"Kasungu\",
\t\t\"Likoma Island\",
\t\t\"Lilongwe\",
\t\t\"Machinga\",
\t\t\"Mangochi\",
\t\t\"Mchinji\",
\t\t\"Mulanje\",
\t\t\"Mwanza\",
\t\t\"Mzimba\",
\t\t\"Nkhata Bay\",
\t\t\"Nkhotakota\",
\t\t\"Nsanje\",
\t\t\"Ntcheu\",
\t\t\"Ntchisi\",
\t\t\"Phalomba\",
\t\t\"Rumphi\",
\t\t\"Salima\",
\t\t\"Thyolo\",
\t\t\"Zomba\"
\t],
\t\"Malaysia\": [
\t\t\"Wilayah Persekutuan Kuala Lumpur\",
\t\t\"Wilayah Persekutuan Labuan\",
\t\t\"Wilayah Persekutuan Putrajaya\",
\t\t\"Johor\",
\t\t\"Kedah\",
\t\t\"Kelantan\",
\t\t\"Melaka\",
\t\t\"Negeri Sembilan\",
\t\t\"Pahang\",
\t\t\"Perak\",
\t\t\"Perlis\",
\t\t\"Pulau Pinang\",
\t\t\"Sabah\",
\t\t\"Sarawak\",
\t\t\"Selangor\",
\t\t\"Terengganu\"
\t],
\t\"Mozambique\": [
\t\t\"Maputo\",
\t\t\"Cabo Delgado\",
\t\t\"Inhambane\",
\t\t\"Manica\",
\t\t\"Numpula\",
\t\t\"Niaaea\",
\t\t\"Sofala\",
\t\t\"Tete\",
\t\t\"Zambezia\"
\t],
\t\"Namibia\": [
\t\t\"Caprivi\",
\t\t\"Erongo\",
\t\t\"Hardap\",
\t\t\"Karas\",
\t\t\"Khomae\",
\t\t\"Kunene\",
\t\t\"Ohangwena\",
\t\t\"Okavango\",
\t\t\"Omaheke\",
\t\t\"Omusati\",
\t\t\"Oshana\",
\t\t\"Oshikoto\",
\t\t\"Otjozondjupa\"
\t],
\t\"Niger\": [
\t\t\"Niamey\",
\t\t\"Agadez\",
\t\t\"Diffa\",
\t\t\"Dosso\",
\t\t\"Maradi\",
\t\t\"Tahoua\",
\t\t\"Tillaberi\",
\t\t\"Zinder\"
\t],
\t\"Nigeria\": [
\t\t\"Abuja Capital Territory\",
\t\t\"Abia\",
\t\t\"Adamawa\",
\t\t\"Akwa Ibom\",
\t\t\"Anambra\",
\t\t\"Bauchi\",
\t\t\"Bayelsa\",
\t\t\"Benue\",
\t\t\"Borno\",
\t\t\"Cross River\",
\t\t\"Delta\",
\t\t\"Ebonyi\",
\t\t\"Edo\",
\t\t\"Ekiti\",
\t\t\"Enugu\",
\t\t\"Gombe\",
\t\t\"Imo\",
\t\t\"Jigawa\",
\t\t\"Kaduna\",
\t\t\"Kano\",
\t\t\"Katsina\",
\t\t\"Kebbi\",
\t\t\"Kogi\",
\t\t\"Kwara\",
\t\t\"Lagos\",
\t\t\"Nassarawa\",
\t\t\"Niger\",
\t\t\"Ogun\",
\t\t\"Ondo\",
\t\t\"Osun\",
\t\t\"Oyo\",
\t\t\"Rivers\",
\t\t\"Sokoto\",
\t\t\"Taraba\",
\t\t\"Yobe\",
\t\t\"Zamfara\"
\t],
\t\"Nicaragua\": [
\t\t\"Boaco\",
\t\t\"Carazo\",
\t\t\"Chinandega\",
\t\t\"Chontales\",
\t\t\"Esteli\",
\t\t\"Jinotega\",
\t\t\"Leon\",
\t\t\"Madriz\",
\t\t\"Managua\",
\t\t\"Masaya\",
\t\t\"Matagalpa\",
\t\t\"Nueva Segovia\",
\t\t\"Rio San Juan\",
\t\t\"Rivas\",
\t\t\"Atlantico Norte\",
\t\t\"Atlantico Sur\"
\t],
\t\"Norway\": [
\t\t\"Akershus\",
\t\t\"Aust-Agder\",
\t\t\"Buskerud\",
\t\t\"Finumark\",
\t\t\"Hedmark\",
\t\t\"Hordaland\",
\t\t\"Mire og Romsdal\",
\t\t\"Nordland\",
\t\t\"Nord-Trindelag\",
\t\t\"Oppland\",
\t\t\"Oslo\",
\t\t\"Rogaland\",
\t\t\"Sogn og Fjordane\",
\t\t\"Sir-Trindelag\",
\t\t\"Telemark\",
\t\t\"Troms\",
\t\t\"Vest-Agder\",
\t\t\"Vestfold\",
\t\t\"Ostfold\",
\t\t\"Jan Mayen\",
\t\t\"Svalbard\"
\t],
\t\"New Zealand\": [
\t\t\"Auckland\",
\t\t\"Bay of Plenty\",
\t\t\"Canterbury\",
\t\t\"Gisborne\",
\t\t\"Hawkes Bay\",
\t\t\"Manawatu-Wanganui\",
\t\t\"Marlborough\",
\t\t\"Nelson\",
\t\t\"Northland\",
\t\t\"Otago\",
\t\t\"Southland\",
\t\t\"Taranaki\",
\t\t\"Tasman\",
\t\t\"waikato\",
\t\t\"Wellington\",
\t\t\"West Coast\"
\t],
\t\"Oman\": [
\t\t\"Ad Dakhillyah\",
\t\t\"Ad Dhahirah\",
\t\t\"Al Batinah North\",
\t\t\"Al Batinah South\",
\t\t\"Al Buraymi\",
\t\t\"Al Wusta\",
\t\t\"Ash Sharqlyah North\",
\t\t\"Ash Sharqlyah South\",
\t\t\"Dhofar\",
\t\t\"Muscat\",
\t\t\"Musandam\"
\t],
\t\"Panama\": [
\t\t\"Bocas del Toro\",
\t\t\"Cocle\",
\t\t\"Chiriqui\",
\t\t\"Darien\",
\t\t\"Herrera\",
\t\t\"Loa Santoa\",
\t\t\"Panama\",
\t\t\"Veraguas\",
\t\t\"Comarca de San Blas\"
\t],
\t\"Peru\": [
\t\t\"El Callao\",
\t\t\"Ancash\",
\t\t\"Apurimac\",
\t\t\"Arequipa\",
\t\t\"Ayacucho\",
\t\t\"Cajamarca\",
\t\t\"Cuzco\",
\t\t\"Huancavelica\",
\t\t\"Huanuco\",
\t\t\"Ica\",
\t\t\"Junin\",
\t\t\"La Libertad\",
\t\t\"Lambayeque\",
\t\t\"Lima\",
\t\t\"Loreto\",
\t\t\"Madre de Dios\",
\t\t\"Moquegua\",
\t\t\"Pasco\",
\t\t\"Piura\",
\t\t\"Puno\",
\t\t\"San Martin\",
\t\t\"Tacna\",
\t\t\"Tumbes\",
\t\t\"Ucayali\"
\t],
\t\"Papua New Guinea\": [
\t\t\"National Capital District (Port Moresby)\",
\t\t\"Chimbu\",
\t\t\"Eastern Highlands\",
\t\t\"East New Britain\",
\t\t\"East Sepik\",
\t\t\"Enga\",
\t\t\"Gulf\",
\t\t\"Madang\",
\t\t\"Manus\",
\t\t\"Milne Bay\",
\t\t\"Morobe\",
\t\t\"New Ireland\",
\t\t\"North Solomons\",
\t\t\"Santaun\",
\t\t\"Southern Highlands\",
\t\t\"Western Highlands\",
\t\t\"West New Britain\"
\t],
\t\"Philippines\": [
\t\t\"Abra\",
\t\t\"Agusan del Norte\",
\t\t\"Agusan del Sur\",
\t\t\"Aklan\",
\t\t\"Albay\",
\t\t\"Antique\",
\t\t\"Apayao\",
\t\t\"Aurora\",
\t\t\"Basilan\",
\t\t\"Batasn\",
\t\t\"Batanes\",
\t\t\"Batangas\",
\t\t\"Benguet\",
\t\t\"Biliran\",
\t\t\"Bohol\",
\t\t\"Bukidnon\",
\t\t\"Bulacan\",
\t\t\"Cagayan\",
\t\t\"Camarines Norte\",
\t\t\"Camarines Sur\",
\t\t\"Camiguin\",
\t\t\"Capiz\",
\t\t\"Catanduanes\",
\t\t\"Cavite\",
\t\t\"Cebu\",
\t\t\"Compostela Valley\",
\t\t\"Davao\",
\t\t\"Davao del Sur\",
\t\t\"Davao Oriental\",
\t\t\"Eastern Samar\",
\t\t\"Guimaras\",
\t\t\"Ifugao\",
\t\t\"Ilocos Norte\",
\t\t\"Ilocos Sur\",
\t\t\"Iloilo\",
\t\t\"Isabela\",
\t\t\"Kalinga-Apayso\",
\t\t\"Laguna\",
\t\t\"Lanao del Norte\",
\t\t\"Lanao del Sur\",
\t\t\"La Union\",
\t\t\"Leyte\",
\t\t\"Maguindanao\",
\t\t\"Marinduque\",
\t\t\"Masbate\",
\t\t\"Mindoro Occidental\",
\t\t\"Mindoro Oriental\",
\t\t\"Misamis Occidental\",
\t\t\"Misamis Oriental\",
\t\t\"Mountain Province\",
\t\t\"Negroe Occidental\",
\t\t\"Negros Oriental\",
\t\t\"North Cotabato\",
\t\t\"Northern Samar\",
\t\t\"Nueva Ecija\",
\t\t\"Nueva Vizcaya\",
\t\t\"Palawan\",
\t\t\"Pampanga\",
\t\t\"Pangasinan\",
\t\t\"Quezon\",
\t\t\"Quirino\",
\t\t\"Rizal\",
\t\t\"Romblon\",
\t\t\"Sarangani\",
\t\t\"Siquijor\",
\t\t\"Sorsogon\",
\t\t\"South Cotabato\",
\t\t\"Southern Leyte\",
\t\t\"Sultan Kudarat\",
\t\t\"Sulu\",
\t\t\"Surigao del Norte\",
\t\t\"Surigao del Sur\",
\t\t\"Tarlac\",
\t\t\"Tawi-Tawi\",
\t\t\"Western Samar\",
\t\t\"Zambales\",
\t\t\"Zamboanga del Norte\",
\t\t\"Zamboanga del Sur\",
\t\t\"Zamboanga Sibiguey\"
\t],
\t\"Pakistan\": [
\t\t\"Islamabad\",
\t\t\"Baluchistan (en)\",
\t\t\"North-West Frontier\",
\t\t\"Sind (en)\",
\t\t\"Federally Administered Tribal Aresa\",
\t\t\"Azad Rashmir\",
\t\t\"Northern Areas\"
\t],
\t\"Portugal\": [
\t\t\"Aveiro\",
\t\t\"Beja\",
\t\t\"Braga\",
\t\t\"Bragan\\u00e7a\",
\t\t\"Castelo Branco\",
\t\t\"Coimbra\",
\t\t\"\\u00c9vora\",
\t\t\"Faro\",
\t\t\"Guarda\",
\t\t\"Leiria\",
\t\t\"Lisboa\",
\t\t\"Portalegre\",
\t\t\"Porto\",
\t\t\"Santar\\u00e9m\",
\t\t\"Set\\u00fabal\",
\t\t\"Viana do Castelo\",
\t\t\"Vila Real\",
\t\t\"Viseu\",
\t\t\"Regi\\u00e3o Aut\\u00f3noma dos A\\u00e7ores\",
\t\t\"Regi\\u00e3o Aut\\u00f3noma da Madeira\"
\t],
\t\"Paraguay\": [
\t\t\"Asuncion\",
\t\t\"Alto Paraguay\",
\t\t\"Alto Parana\",
\t\t\"Amambay\",
\t\t\"Boqueron\",
\t\t\"Caeguazu\",
\t\t\"Caazapl\",
\t\t\"Canindeyu\",
\t\t\"Concepcion\",
\t\t\"Cordillera\",
\t\t\"Guaira\",
\t\t\"Itapua\",
\t\t\"Miaiones\",
\t\t\"Neembucu\",
\t\t\"Paraguari\",
\t\t\"Presidente Hayes\",
\t\t\"San Pedro\"
\t],
\t\"Qatar\": [
\t\t\"Ad Dawhah\",
\t\t\"Al Ghuwayriyah\",
\t\t\"Al Jumayliyah\",
\t\t\"Al Khawr\",
\t\t\"Al Wakrah\",
\t\t\"Ar Rayyan\",
\t\t\"Jariyan al Batnah\",
\t\t\"Madinat ash Shamal\",
\t\t\"Umm Salal\"
\t],
\t\"Romania\": [
\t\t\"Bucuresti\",
\t\t\"Alba\",
\t\t\"Arad\",
\t\t\"Arges\",
\t\t\"Bacau\",
\t\t\"Bihor\",
\t\t\"Bistrita-Nasaud\",
\t\t\"Boto'ani\",
\t\t\"Bra'ov\",
\t\t\"Braila\",
\t\t\"Buzau\",
\t\t\"Caras-Severin\",
\t\t\"Ca la ras'i\",
\t\t\"Cluj\",
\t\t\"Constant'a\",
\t\t\"Covasna\",
\t\t\"Dambovit'a\",
\t\t\"Dolj\",
\t\t\"Galat'i\",
\t\t\"Giurgiu\",
\t\t\"Gorj\",
\t\t\"Harghita\",
\t\t\"Hunedoara\",
\t\t\"Ialomit'a\",
\t\t\"Ias'i\",
\t\t\"Ilfov\",
\t\t\"Maramures\",
\t\t\"Mehedint'i\",
\t\t\"Mures\",
\t\t\"Neamt\",
\t\t\"Olt\",
\t\t\"Prahova\",
\t\t\"Satu Mare\",
\t\t\"Sa laj\",
\t\t\"Sibiu\",
\t\t\"Suceava\",
\t\t\"Teleorman\",
\t\t\"Timis\",
\t\t\"Tulcea\",
\t\t\"Vaslui\",
\t\t\"Valcea\",
\t\t\"Vrancea\"
\t],
\t\"Russian Federation\": [
\t\t\"Adygeya, Respublika\",
\t\t\"Altay, Respublika\",
\t\t\"Bashkortostan, Respublika\",
\t\t\"Buryatiya, Respublika\",
\t\t\"Chechenskaya Respublika\",
\t\t\"Chuvashskaya Respublika\",
\t\t\"Dagestan, Respublika\",
\t\t\"Ingushskaya Respublika\",
\t\t\"Kabardino-Balkarskaya\",
\t\t\"Kalmykiya, Respublika\",
\t\t\"Karachayevo-Cherkesskaya Respublika\",
\t\t\"Kareliya, Respublika\",
\t\t\"Khakasiya, Respublika\",
\t\t\"Komi, Respublika\",
\t\t\"Mariy El, Respublika\",
\t\t\"Mordoviya, Respublika\",
\t\t\"Sakha, Respublika [Yakutiya]\",
\t\t\"Severnaya Osetiya, Respublika\",
\t\t\"Tatarstan, Respublika\",
\t\t\"Tyva, Respublika [Tuva]\",
\t\t\"Udmurtskaya Respublika\",
\t\t\"Altayskiy kray\",
\t\t\"Khabarovskiy kray\",
\t\t\"Krasnodarskiy kray\",
\t\t\"Krasnoyarskiy kray\",
\t\t\"Primorskiy kray\",
\t\t\"Stavropol'skiy kray\",
\t\t\"Amurskaya oblast'\",
\t\t\"Arkhangel'skaya oblast'\",
\t\t\"Astrakhanskaya oblast'\",
\t\t\"Belgorodskaya oblast'\",
\t\t\"Bryanskaya oblast'\",
\t\t\"Chelyabinskaya oblast'\",
\t\t\"Chitinskaya oblast'\",
\t\t\"Irkutskaya oblast'\",
\t\t\"Ivanovskaya oblast'\",
\t\t\"Kaliningradskaya oblast'\",
\t\t\"Kaluzhskaya oblast'\",
\t\t\"Kamchatskaya oblast'\",
\t\t\"Kemerovskaya oblast'\",
\t\t\"Kirovskaya oblast'\",
\t\t\"Kostromskaya oblast'\",
\t\t\"Kurganskaya oblast'\",
\t\t\"Kurskaya oblast'\",
\t\t\"Leningradskaya oblast'\",
\t\t\"Lipetskaya oblast'\",
\t\t\"Magadanskaya oblast'\",
\t\t\"Moskovskaya oblast'\",
\t\t\"Murmanskaya oblast'\",
\t\t\"Nizhegorodskaya oblast'\",
\t\t\"Novgorodskaya oblast'\",
\t\t\"Novosibirskaya oblast'\",
\t\t\"Omskaya oblast'\",
\t\t\"Orenburgskaya oblast'\",
\t\t\"Orlovskaya oblast'\",
\t\t\"Penzenskaya oblast'\",
\t\t\"Permskaya oblast'\",
\t\t\"Pskovskaya oblast'\",
\t\t\"Rostovskaya oblast'\",
\t\t\"Ryazanskaya oblast'\",
\t\t\"Sakhalinskaya oblast'\",
\t\t\"Samarskaya oblast'\",
\t\t\"Saratovskaya oblast'\",
\t\t\"Smolenskaya oblast'\",
\t\t\"Sverdlovskaya oblast'\",
\t\t\"Tambovskaya oblast'\",
\t\t\"Tomskaya oblast'\",
\t\t\"Tul'skaya oblast'\",
\t\t\"Tverskaya oblast'\",
\t\t\"Tyumenskaya oblast'\",
\t\t\"Ul'yanovskaya oblast'\",
\t\t\"Vladimirskaya oblast'\",
\t\t\"Volgogradskaya oblast'\",
\t\t\"Vologodskaya oblast'\",
\t\t\"Voronezhskaya oblast'\",
\t\t\"Yaroslavskaya oblast'\",
\t\t\"Moskva\",
\t\t\"Sankt-Peterburg\",
\t\t\"Yevreyskaya avtonomnaya oblast'\",
\t\t\"Aginskiy Buryatskiy avtonomnyy\",
\t\t\"Chukotskiy avtonomnyy okrug\",
\t\t\"Evenkiyskiy avtonomnyy okrug\",
\t\t\"Khanty-Mansiyskiy avtonomnyy okrug\",
\t\t\"Komi-Permyatskiy avtonomnyy okrug\",
\t\t\"Koryakskiy avtonomnyy okrug\",
\t\t\"Nenetskiy avtonomnyy okrug\",
\t\t\"Taymyrskiy (Dolgano-Nenetskiy)\",
\t\t\"Ust'-Ordynskiy Buryatskiy\",
\t\t\"Yamalo-Nenetskiy avtonomnyy okrug\"
\t],
\t\"Rwanda\": [
\t\t\"Butare\",
\t\t\"Byumba\",
\t\t\"Cyangugu\",
\t\t\"Gikongoro\",
\t\t\"Gisenyi\",
\t\t\"Gitarama\",
\t\t\"Kibungo\",
\t\t\"Kibuye\",
\t\t\"Kigali-Rural Kigali y' Icyaro\",
\t\t\"Kigali-Ville Kigali Ngari\",
\t\t\"Mutara\",
\t\t\"Ruhengeri\"
\t],
\t\"Saudi Arabia\": [
\t\t\"Al Batah\",
\t\t\"Al H, udd ash Shamallyah\",
\t\t\"Al Jawf\",
\t\t\"Al Madinah\",
\t\t\"Al Qasim\",
\t\t\"Ar Riyad\",
\t\t\"Asir\",
\t\t\"Ha'il\",
\t\t\"Jlzan\",
\t\t\"Makkah\",
\t\t\"Najran\",
\t\t\"Tabuk\"
\t],
\t\"Solomon Islands\": [
\t\t\"Capital Territory (Honiara)\",
\t\t\"Guadalcanal\",
\t\t\"Isabel\",
\t\t\"Makira\",
\t\t\"Malaita\",
\t\t\"Temotu\"
\t],
\t\"Sudan\": [
\t\t\"A'ali an Nil\",
\t\t\"Al Bah al Ahmar\",
\t\t\"Al Buhayrat\",
\t\t\"Al Jazirah\",
\t\t\"Al Khartum\",
\t\t\"Al Qadarif\",
\t\t\"Al Wahdah\",
\t\t\"An Nil\",
\t\t\"An Nil al Abyaq\",
\t\t\"An Nil al Azraq\",
\t\t\"Ash Shamallyah\",
\t\t\"Bahr al Jabal\",
\t\t\"Gharb al Istiwa'iyah\",
\t\t\"Gharb Ba~r al Ghazal\",
\t\t\"Gharb Darfur\",
\t\t\"Gharb Kurdufan\",
\t\t\"Janub Darfur\",
\t\t\"Janub Rurdufan\",
\t\t\"Jnqall\",
\t\t\"Kassala\",
\t\t\"Shamal Batr al Ghazal\",
\t\t\"Shamal Darfur\",
\t\t\"Shamal Kurdufan\",
\t\t\"Sharq al Istiwa'iyah\",
\t\t\"Sinnar\",
\t\t\"Warab\"
\t],
\t\"Sweden\": [
\t\t\"Blekinge lan\",
\t\t\"Dalarnas lan\",
\t\t\"Gotlands lan\",
\t\t\"Gavleborge lan\",
\t\t\"Hallands lan\",
\t\t\"Jamtlande lan\",
\t\t\"Jonkopings lan\",
\t\t\"Kalmar lan\",
\t\t\"Kronoberge lan\",
\t\t\"Norrbottena lan\",
\t\t\"Skane lan\",
\t\t\"Stockholms lan\",
\t\t\"Sodermanlands lan\",
\t\t\"Uppsala lan\",
\t\t\"Varmlanda lan\",
\t\t\"Vasterbottens lan\",
\t\t\"Vasternorrlands lan\",
\t\t\"Vastmanlanda lan\",
\t\t\"Vastra Gotalands lan\",
\t\t\"Orebro lan\",
\t\t\"Ostergotlands lan\"
\t],
\t\"Saint Helena\": [
\t\t\"Saint Helena\",
\t\t\"Ascension\",
\t\t\"Tristan da Cunha\"
\t],
\t\"Slovenia\": [
\t\t\"Ajdovscina\",
\t\t\"Beltinci\",
\t\t\"Benedikt\",
\t\t\"Bistrica ob Sotli\",
\t\t\"Bled\",
\t\t\"Bloke\",
\t\t\"Bohinj\",
\t\t\"Borovnica\",
\t\t\"Bovec\",
\t\t\"Braslovce\",
\t\t\"Brda\",
\t\t\"Brezovica\",
\t\t\"Brezica\",
\t\t\"Cankova\",
\t\t\"Celje\",
\t\t\"Cerklje na Gorenjskem\",
\t\t\"Cerknica\",
\t\t\"Cerkno\",
\t\t\"Cerkvenjak\",
\t\t\"Crensovci\",
\t\t\"Crna na Koroskem\",
\t\t\"Crnomelj\",
\t\t\"Destrnik\",
\t\t\"Divaca\",
\t\t\"Dobje\",
\t\t\"Dobrepolje\",
\t\t\"Dobrna\",
\t\t\"Dobrova-Polhov Gradec\",
\t\t\"Dobrovnik\",
\t\t\"Dol pri Ljubljani\",
\t\t\"Dolenjske Toplice\",
\t\t\"Domzale\",
\t\t\"Dornava\",
\t\t\"Dravograd\",
\t\t\"Duplek\",
\t\t\"Gorenja vas-Poljane\",
\t\t\"Gorsnica\",
\t\t\"Gornja Radgona\",
\t\t\"Gornji Grad\",
\t\t\"Gornji Petrovci\",
\t\t\"Grad\",
\t\t\"Grosuplje\",
\t\t\"Hajdina\",
\t\t\"Hoce-Slivnica\",
\t\t\"Hodos\",
\t\t\"Jorjul\",
\t\t\"Hrastnik\",
\t\t\"Hrpelje-Kozina\",
\t\t\"Idrija\",
\t\t\"Ig\",
\t\t\"IIrska Bistrica\",
\t\t\"Ivancna Gorica\",
\t\t\"Izola\",
\t\t\"Jesenice\",
\t\t\"Jezersko\",
\t\t\"Jursinci\",
\t\t\"Kamnik\",
\t\t\"Kanal\",
\t\t\"Kidricevo\",
\t\t\"Kobarid\",
\t\t\"Kobilje\",
\t\t\"Jovevje\",
\t\t\"Komen\",
\t\t\"Komenda\",
\t\t\"Koper\",
\t\t\"Kostel\",
\t\t\"Kozje\",
\t\t\"Kranj\",
\t\t\"Kranjska Gora\",
\t\t\"Krizevci\",
\t\t\"Krsko\",
\t\t\"Kungota\",
\t\t\"Kuzma\",
\t\t\"Lasko\",
\t\t\"Lenart\",
\t\t\"Lendava\",
\t\t\"Litija\",
\t\t\"Ljubljana\",
\t\t\"Ljubno\",
\t\t\"Ljutomer\",
\t\t\"Logatec\",
\t\t\"Loska dolina\",
\t\t\"Loski Potok\",
\t\t\"Lovrenc na Pohorju\",
\t\t\"Luce\",
\t\t\"Lukovica\",
\t\t\"Majsperk\",
\t\t\"Maribor\",
\t\t\"Markovci\",
\t\t\"Medvode\",
\t\t\"Menges\",
\t\t\"Metlika\",
\t\t\"Mezica\",
\t\t\"Miklavz na Dravskern polju\",
\t\t\"Miren-Kostanjevica\",
\t\t\"Mirna Pec\",
\t\t\"Mislinja\",
\t\t\"Moravce\",
\t\t\"Moravske Toplice\",
\t\t\"Mozirje\",
\t\t\"Murska Sobota\",
\t\t\"Muta\",
\t\t\"Naklo\",
\t\t\"Nazarje\",
\t\t\"Nova Gorica\",
\t\t\"Nova mesto\",
\t\t\"Sveta Ana\",
\t\t\"Sveti Andraz v Slovenskih goricah\",
\t\t\"Sveti Jurij\",
\t\t\"Salovci\",
\t\t\"Sempeter-Vrtojba\",
\t\t\"Sencur\",
\t\t\"Sentilj\",
\t\t\"Sentjernej\",
\t\t\"Sentjur pri Celju\",
\t\t\"Skocjan\",
\t\t\"Skofja Loka\",
\t\t\"Skoftjica\",
\t\t\"Smarje pri Jelsah\",
\t\t\"Smartno ob Paki\",
\t\t\"Smartno pri Litiji\",
\t\t\"Sostanj\",
\t\t\"Store\",
\t\t\"Tabor\",
\t\t\"Tisina\",
\t\t\"Tolmin\",
\t\t\"Trbovje\",
\t\t\"Trebnje\",
\t\t\"Trnovska vas\",
\t\t\"Trzic\",
\t\t\"Trzin\",
\t\t\"Turnisce\",
\t\t\"Velenje\",
\t\t\"Velika Polana\",
\t\t\"Velika Lasce\",
\t\t\"Verzej\",
\t\t\"Videm\",
\t\t\"Vipava\",
\t\t\"Vitanje\",
\t\t\"Vojnik\",
\t\t\"Vransko\",
\t\t\"Vrhnika\",
\t\t\"Vuzenica\",
\t\t\"Zagorje ob Savi\",
\t\t\"Zavrc\",
\t\t\"Zrece\",
\t\t\"Zalec\",
\t\t\"Zelezniki\",
\t\t\"Zetale\",
\t\t\"Ziri\",
\t\t\"Zirovnica\",
\t\t\"Zuzemberk\"
\t],
\t\"Slovakia\": [
\t\t\"Banskobystrick\\u00fd kraj\",
\t\t\"Bratislavsk\\u00fd kraj\",
\t\t\"Ko\\u0161ick\\u00fd kraj\",
\t\t\"Nitriansky kraj\",
\t\t\"Pre\\u0161ovsk\\u00fd kraj\",
\t\t\"Tren\\u010diansky kraj\",
\t\t\"Trnavsk\\u00fd kraj\",
\t\t\"\\u017dilinsk\\u00fd kraj\"
\t],
\t\"Sierra Leone\": [
\t\t\"Western Area (Freetown)\"
\t],
\t\"Senegal\": [
\t\t\"Dakar\",
\t\t\"Diourbel\",
\t\t\"Fatick\",
\t\t\"Kaolack\",
\t\t\"Kolda\",
\t\t\"Louga\",
\t\t\"Matam\",
\t\t\"Saint-Louis\",
\t\t\"Tambacounda\",
\t\t\"Thies\",
\t\t\"Ziguinchor\"
\t],
\t\"Somalia\": [
\t\t\"Awdal\",
\t\t\"Bakool\",
\t\t\"Banaadir\",
\t\t\"Bay\",
\t\t\"Galguduud\",
\t\t\"Gedo\",
\t\t\"Hiirsan\",
\t\t\"Jubbada Dhexe\",
\t\t\"Jubbada Hoose\",
\t\t\"Mudug\",
\t\t\"Nugaal\",
\t\t\"Saneag\",
\t\t\"Shabeellaha Dhexe\",
\t\t\"Shabeellaha Hoose\",
\t\t\"Sool\",
\t\t\"Togdheer\",
\t\t\"Woqooyi Galbeed\"
\t],
\t\"Suriname\": [
\t\t\"Brokopondo\",
\t\t\"Commewijne\",
\t\t\"Coronie\",
\t\t\"Marowijne\",
\t\t\"Nickerie\",
\t\t\"Paramaribo\",
\t\t\"Saramacca\",
\t\t\"Sipaliwini\",
\t\t\"Wanica\"
\t],
\t\"Sao Tome and Principe\": [
\t\t\"Principe\",
\t\t\"Sao Tome\"
\t],
\t\"El Salvador\": [
\t\t\"Ahuachapan\",
\t\t\"Cabanas\",
\t\t\"Cuscatlan\",
\t\t\"Chalatenango\",
\t\t\"Morazan\",
\t\t\"San Miguel\",
\t\t\"San Salvador\",
\t\t\"Santa Ana\",
\t\t\"San Vicente\",
\t\t\"Sonsonate\",
\t\t\"Usulutan\"
\t],
\t\"Syrian Arab Republic\": [
\t\t\"Al Hasakah\",
\t\t\"Al Ladhiqiyah\",
\t\t\"Al Qunaytirah\",
\t\t\"Ar Raqqah\",
\t\t\"As Suwayda'\",
\t\t\"Dar'a\",
\t\t\"Dayr az Zawr\",
\t\t\"Dimashq\",
\t\t\"Halab\",
\t\t\"Hamah\",
\t\t\"Jim'\",
\t\t\"Idlib\",
\t\t\"Rif Dimashq\",
\t\t\"Tarts\"
\t],
\t\"Eswatini\": [
\t\t\"Hhohho\",
\t\t\"Lubombo\",
\t\t\"Manzini\",
\t\t\"Shiselweni\"
\t],
\t\"Chad\": [
\t\t\"Batha\",
\t\t\"Biltine\",
\t\t\"Borkou-Ennedi-Tibesti\",
\t\t\"Chari-Baguirmi\",
\t\t\"Guera\",
\t\t\"Kanem\",
\t\t\"Lac\",
\t\t\"Logone-Occidental\",
\t\t\"Logone-Oriental\",
\t\t\"Mayo-Kebbi\",
\t\t\"Moyen-Chari\",
\t\t\"Ouaddai\",
\t\t\"Salamat\",
\t\t\"Tandjile\"
\t],
\t\"Togo\": [
\t\t\"Kara\",
\t\t\"Maritime (Region)\",
\t\t\"Savannes\"
\t],
\t\"Thailand\": [
\t\t\"Krung Thep Maha Nakhon Bangkok\",
\t\t\"Phatthaya\",
\t\t\"Amnat Charoen\",
\t\t\"Ang Thong\",
\t\t\"Buri Ram\",
\t\t\"Chachoengsao\",
\t\t\"Chai Nat\",
\t\t\"Chaiyaphum\",
\t\t\"Chanthaburi\",
\t\t\"Chiang Mai\",
\t\t\"Chiang Rai\",
\t\t\"Chon Buri\",
\t\t\"Chumphon\",
\t\t\"Kalasin\",
\t\t\"Kamphasng Phet\",
\t\t\"Kanchanaburi\",
\t\t\"Khon Kaen\",
\t\t\"Krabi\",
\t\t\"Lampang\",
\t\t\"Lamphun\",
\t\t\"Loei\",
\t\t\"Lop Buri\",
\t\t\"Mae Hong Son\",
\t\t\"Maha Sarakham\",
\t\t\"Mukdahan\",
\t\t\"Nakhon Nayok\",
\t\t\"Nakhon Pathom\",
\t\t\"Nakhon Phanom\",
\t\t\"Nakhon Ratchasima\",
\t\t\"Nakhon Sawan\",
\t\t\"Nakhon Si Thammarat\",
\t\t\"Nan\",
\t\t\"Narathiwat\",
\t\t\"Nong Bua Lam Phu\",
\t\t\"Nong Khai\",
\t\t\"Nonthaburi\",
\t\t\"Pathum Thani\",
\t\t\"Pattani\",
\t\t\"Phangnga\",
\t\t\"Phatthalung\",
\t\t\"Phayao\",
\t\t\"Phetchabun\",
\t\t\"Phetchaburi\",
\t\t\"Phichit\",
\t\t\"Phitsanulok\",
\t\t\"Phrae\",
\t\t\"Phra Nakhon Si Ayutthaya\",
\t\t\"Phaket\",
\t\t\"Prachin Buri\",
\t\t\"Prachuap Khiri Khan\",
\t\t\"Ranong\",
\t\t\"Ratchaburi\",
\t\t\"Rayong\",
\t\t\"Roi Et\",
\t\t\"Sa Kaeo\",
\t\t\"Sakon Nakhon\",
\t\t\"Samut Prakan\",
\t\t\"Samut Sakhon\",
\t\t\"Samut Songkhram\",
\t\t\"Saraburi\",
\t\t\"Satun\",
\t\t\"Sing Buri\",
\t\t\"Si Sa Ket\",
\t\t\"Songkhla\",
\t\t\"Sukhothai\",
\t\t\"Suphan Buri\",
\t\t\"Surat Thani\",
\t\t\"Surin\",
\t\t\"Tak\",
\t\t\"Trang\",
\t\t\"Trat\",
\t\t\"Ubon Ratchathani\",
\t\t\"Udon Thani\",
\t\t\"Uthai Thani\",
\t\t\"Uttaradit\",
\t\t\"Yala\",
\t\t\"Yasothon\"
\t],
\t\"Tajikistan\": [
\t\t\"Sughd\",
\t\t\"Khatlon\",
\t\t\"Gorno-Badakhshan\"
\t],
\t\"Turkmenistan\": [
\t\t\"Ahal\",
\t\t\"Balkan\",
\t\t\"Dasoguz\",
\t\t\"Lebap\",
\t\t\"Mary\"
\t],
\t\"Tunisia\": [
\t\t\"B\\u00e9ja\",
\t\t\"Ben Arous\",
\t\t\"Bizerte\",
\t\t\"Gab\\u00e8s\",
\t\t\"Gafsa\",
\t\t\"Jendouba\",
\t\t\"Kairouan\",
\t\t\"Rasserine\",
\t\t\"Kebili\",
\t\t\"L'Ariana\",
\t\t\"Le Ref\",
\t\t\"Mahdia\",
\t\t\"La Manouba\",
\t\t\"Medenine\",
\t\t\"Moneatir\",
\t\t\"Naboul\",
\t\t\"Sfax\",
\t\t\"Sidi Bouxid\",
\t\t\"Siliana\",
\t\t\"Sousse\",
\t\t\"Tataouine\",
\t\t\"Tozeur\",
\t\t\"Tunis\",
\t\t\"Zaghouan\"
\t],
\t\"Türkiye\": [
\t\t\"Adana\",
\t\t\"Ad yaman\",
\t\t\"Afyon\",
\t\t\"Ag r\",
\t\t\"Aksaray\",
\t\t\"Amasya\",
\t\t\"Ankara\",
\t\t\"Antalya\",
\t\t\"Ardahan\",
\t\t\"Artvin\",
\t\t\"Aydin\",
\t\t\"Bal kesir\",
\t\t\"Bartin\",
\t\t\"Batman\",
\t\t\"Bayburt\",
\t\t\"Bilecik\",
\t\t\"Bingol\",
\t\t\"Bitlis\",
\t\t\"Bolu\",
\t\t\"Burdur\",
\t\t\"Bursa\",
\t\t\"Canakkale\",
\t\t\"Cankir\",
\t\t\"Corum\",
\t\t\"Denizli\",
\t\t\"Diyarbakir\",
\t\t\"Duzce\",
\t\t\"Edirne\",
\t\t\"Elazig\",
\t\t\"Erzincan\",
\t\t\"Erzurum\",
\t\t\"Eskis'ehir\",
\t\t\"Gaziantep\",
\t\t\"Giresun\",
\t\t\"Gms'hane\",
\t\t\"Hakkari\",
\t\t\"Hatay\",
\t\t\"Igidir\",
\t\t\"Isparta\",
\t\t\"Icel\",
\t\t\"Istanbul\",
\t\t\"Izmir\",
\t\t\"Kahramanmaras\",
\t\t\"Karabk\",
\t\t\"Karaman\",
\t\t\"Kars\",
\t\t\"Kastamonu\",
\t\t\"Kayseri\",
\t\t\"Kirikkale\",
\t\t\"Kirklareli\",
\t\t\"Kirs'ehir\",
\t\t\"Kilis\",
\t\t\"Kocaeli\",
\t\t\"Konya\",
\t\t\"Ktahya\",
\t\t\"Malatya\",
\t\t\"Manisa\",
\t\t\"Mardin\",
\t\t\"Mugila\",
\t\t\"Mus\",
\t\t\"Nevs'ehir\",
\t\t\"Nigide\",
\t\t\"Ordu\",
\t\t\"Osmaniye\",
\t\t\"Rize\",
\t\t\"Sakarya\",
\t\t\"Samsun\",
\t\t\"Siirt\",
\t\t\"Sinop\",
\t\t\"Sivas\",
\t\t\"S'anliurfa\",
\t\t\"S'rnak\",
\t\t\"Tekirdag\",
\t\t\"Tokat\",
\t\t\"Trabzon\",
\t\t\"Tunceli\",
\t\t\"Us'ak\",
\t\t\"Van\",
\t\t\"Yalova\",
\t\t\"Yozgat\",
\t\t\"Zonguldak\"
\t],
\t\"Trinidad and Tobago\": [
\t\t\"Couva-Tabaquite-Talparo\",
\t\t\"Diego Martin\",
\t\t\"Eastern Tobago\",
\t\t\"Penal-Debe\",
\t\t\"Princes Town\",
\t\t\"Rio Claro-Mayaro\",
\t\t\"Sangre Grande\",
\t\t\"San Juan-Laventille\",
\t\t\"Siparia\",
\t\t\"Tunapuna-Piarco\",
\t\t\"Western Tobago\",
\t\t\"Arima\",
\t\t\"Chaguanas\",
\t\t\"Point Fortin\",
\t\t\"Port of Spain\",
\t\t\"San Fernando\"
\t],
\t\"Timor-Leste\": [
\t\t\"Aileu\",
\t\t\"Ainaro\",
\t\t\"Bacucau\",
\t\t\"Bobonaro\",
\t\t\"Cova Lima\",
\t\t\"Dili\",
\t\t\"Ermera\",
\t\t\"Laulem\",
\t\t\"Liquica\",
\t\t\"Manatuto\",
\t\t\"Manafahi\",
\t\t\"Oecussi\",
\t\t\"Viqueque\"
\t],
\t\"Taiwan\": [
\t\t\"Changhua\",
\t\t\"Chiayi\",
\t\t\"Hsinchu\",
\t\t\"Hualien\",
\t\t\"Ilan\",
\t\t\"Kaohsiung\",
\t\t\"Miaoli\",
\t\t\"Nantou\",
\t\t\"Penghu\",
\t\t\"Pingtung\",
\t\t\"Taichung\",
\t\t\"Tainan\",
\t\t\"Taipei\",
\t\t\"Taitung\",
\t\t\"Taoyuan\",
\t\t\"Yunlin\",
\t\t\"Keelung\"
\t],
\t\"Tanzania, United Republic of\": [
\t\t\"Arusha\",
\t\t\"Dar-es-Salaam\",
\t\t\"Dodoma\",
\t\t\"Iringa\",
\t\t\"Kagera\",
\t\t\"Kaskazini Pemba\",
\t\t\"Kaskazini Unguja\",
\t\t\"Xigoma\",
\t\t\"Kilimanjaro\",
\t\t\"Rusini Pemba\",
\t\t\"Kusini Unguja\",
\t\t\"Lindi\",
\t\t\"Manyara\",
\t\t\"Mara\",
\t\t\"Mbeya\",
\t\t\"Mjini Magharibi\",
\t\t\"Morogoro\",
\t\t\"Mtwara\",
\t\t\"Pwani\",
\t\t\"Rukwa\",
\t\t\"Ruvuma\",
\t\t\"Shinyanga\",
\t\t\"Singida\",
\t\t\"Tabora\",
\t\t\"Tanga\"
\t],
\t\"Ukraine\": [
\t\t\"Cherkas'ka Oblast'\",
\t\t\"Chernihivs'ka Oblast'\",
\t\t\"Chernivets'ka Oblast'\",
\t\t\"Dnipropetrovs'ka Oblast'\",
\t\t\"Donets'ka Oblast'\",
\t\t\"Ivano-Frankivs'ka Oblast'\",
\t\t\"Kharkivs'ka Oblast'\",
\t\t\"Khersons'ka Oblast'\",
\t\t\"Khmel'nyts'ka Oblast'\",
\t\t\"Kirovohrads'ka Oblast'\",
\t\t\"Kyivs'ka Oblast'\",
\t\t\"Luhans'ka Oblast'\",
\t\t\"L'vivs'ka Oblast'\",
\t\t\"Mykolaivs'ka Oblast'\",
\t\t\"Odes 'ka Oblast'\",
\t\t\"Poltavs'ka Oblast'\",
\t\t\"Rivnens'ka Oblast'\",
\t\t\"Sums 'ka Oblast'\",
\t\t\"Ternopil's'ka Oblast'\",
\t\t\"Vinnyts'ka Oblast'\",
\t\t\"Volyos'ka Oblast'\",
\t\t\"Zakarpats'ka Oblast'\",
\t\t\"Zaporiz'ka Oblast'\",
\t\t\"Zhytomyrs'ka Oblast'\",
\t\t\"Respublika Krym\",
\t\t\"Kyiv\",
\t\t\"Sevastopol\"
\t],
\t\"Uganda\": [
\t\t\"Adjumani\",
\t\t\"Apac\",
\t\t\"Arua\",
\t\t\"Bugiri\",
\t\t\"Bundibugyo\",
\t\t\"Bushenyi\",
\t\t\"Busia\",
\t\t\"Gulu\",
\t\t\"Hoima\",
\t\t\"Iganga\",
\t\t\"Jinja\",
\t\t\"Kabale\",
\t\t\"Kabarole\",
\t\t\"Kaberamaido\",
\t\t\"Kalangala\",
\t\t\"Kampala\",
\t\t\"Kamuli\",
\t\t\"Kamwenge\",
\t\t\"Kanungu\",
\t\t\"Kapchorwa\",
\t\t\"Kasese\",
\t\t\"Katakwi\",
\t\t\"Kayunga\",
\t\t\"Kibaale\",
\t\t\"Kiboga\",
\t\t\"Kisoro\",
\t\t\"Kitgum\",
\t\t\"Kotido\",
\t\t\"Kumi\",
\t\t\"Kyenjojo\",
\t\t\"Lira\",
\t\t\"Luwero\",
\t\t\"Masaka\",
\t\t\"Masindi\",
\t\t\"Mayuge\",
\t\t\"Mbale\",
\t\t\"Mbarara\",
\t\t\"Moroto\",
\t\t\"Moyo\",
\t\t\"Mpigi\",
\t\t\"Mubende\",
\t\t\"Mukono\",
\t\t\"Nakapiripirit\",
\t\t\"Nakasongola\",
\t\t\"Nebbi\",
\t\t\"Ntungamo\",
\t\t\"Pader\",
\t\t\"Pallisa\",
\t\t\"Rakai\",
\t\t\"Rukungiri\",
\t\t\"Sembabule\",
\t\t\"Sironko\",
\t\t\"Soroti\",
\t\t\"Tororo\",
\t\t\"Wakiso\",
\t\t\"Yumbe\"
\t],
\t\"United States Minor Outlying Islands\": [
\t\t\"Baker Island\",
\t\t\"Howland Island\",
\t\t\"Jarvis Island\",
\t\t\"Johnston Atoll\",
\t\t\"Kingman Reef\",
\t\t\"Midway Islands\",
\t\t\"Navassa Island\",
\t\t\"Palmyra Atoll\",
\t\t\"Wake Ialand\"
\t],
\t\"Uruguay\": [
\t\t\"Artigsa\",
\t\t\"Canelones\",
\t\t\"Cerro Largo\",
\t\t\"Colonia\",
\t\t\"Durazno\",
\t\t\"Flores\",
\t\t\"Lavalleja\",
\t\t\"Maldonado\",
\t\t\"Montevideo\",
\t\t\"Paysandu\",
\t\t\"Rivera\",
\t\t\"Rocha\",
\t\t\"Salto\",
\t\t\"Soriano\",
\t\t\"Tacuarembo\",
\t\t\"Treinta y Tres\"
\t],
\t\"Uzbekistan\": [
\t\t\"Toshkent (city)\",
\t\t\"Qoraqalpogiston Respublikasi\",
\t\t\"Andijon\",
\t\t\"Buxoro\",
\t\t\"Farg'ona\",
\t\t\"Jizzax\",
\t\t\"Khorazm\",
\t\t\"Namangan\",
\t\t\"Navoiy\",
\t\t\"Qashqadaryo\",
\t\t\"Samarqand\",
\t\t\"Sirdaryo\",
\t\t\"Surxondaryo\",
\t\t\"Toshkent\",
\t\t\"Xorazm\"
\t],
\t\"Venezuela\": [
\t\t\"Diatrito Federal\",
\t\t\"Anzoategui\",
\t\t\"Apure\",
\t\t\"Aragua\",
\t\t\"Barinas\",
\t\t\"Carabobo\",
\t\t\"Cojedes\",
\t\t\"Falcon\",
\t\t\"Guarico\",
\t\t\"Lara\",
\t\t\"Merida\",
\t\t\"Miranda\",
\t\t\"Monagas\",
\t\t\"Nueva Esparta\",
\t\t\"Portuguesa\",
\t\t\"Tachira\",
\t\t\"Trujillo\",
\t\t\"Vargas\",
\t\t\"Yaracuy\",
\t\t\"Zulia\",
\t\t\"Delta Amacuro\",
\t\t\"Dependencias Federales\"
\t],
\t\"Vanuatu\": [
\t\t\"Malampa\",
\t\t\"Penama\",
\t\t\"Sanma\",
\t\t\"Shefa\",
\t\t\"Tafea\",
\t\t\"Torba\"
\t],
\t\"Samoa\": [
\t\t\"A'ana\",
\t\t\"Aiga-i-le-Tai\",
\t\t\"Atua\",
\t\t\"Fa'aaaleleaga\",
\t\t\"Gaga'emauga\",
\t\t\"Gagaifomauga\",
\t\t\"Palauli\",
\t\t\"Satupa'itea\",
\t\t\"Tuamasaga\",
\t\t\"Va'a-o-Fonoti\",
\t\t\"Vaisigano\"
\t],
\t\"Serbia and Montenegro\": [
\t\t\"Crna Gora\",
\t\t\"Srbija\",
\t\t\"Kosovo-Metohija\",
\t\t\"Vojvodina\"
\t],
\t\"Yemen\": [
\t\t\"Abyan\",
\t\t\"Adan\",
\t\t\"Ad Dali\",
\t\t\"Al Bayda'\",
\t\t\"Al Hudaydah\",
\t\t\"Al Mahrah\",
\t\t\"Al Mahwit\",
\t\t\"Amran\",
\t\t\"Dhamar\",
\t\t\"Hadramawt\",
\t\t\"Hajjah\",
\t\t\"Ibb\",
\t\t\"Lahij\",
\t\t\"Ma'rib\",
\t\t\"Sa'dah\",
\t\t\"San'a'\",
\t\t\"Shabwah\",
\t\t\"Ta'izz\"
\t],
\t\"South Africa\": [
\t\t\"Eastern Cape\",
\t\t\"Free State\",
\t\t\"Gauteng\",
\t\t\"Kwazulu-Natal\",
\t\t\"Mpumalanga\",
\t\t\"Northern Cape\",
\t\t\"Limpopo\",
\t\t\"Western Cape\",
\t\t\"North West\"
\t],
\t\"Zambia\": [
\t\t\"Copperbelt\",
\t\t\"Luapula\",
\t\t\"Lusaka\",
\t\t\"North-Western\"
\t],
\t\"Zimbabwe\": [
\t\t\"Bulawayo\",
\t\t\"Harare\",
\t\t\"Manicaland\",
\t\t\"Mashonaland Central\",
\t\t\"Mashonaland East\",
\t\t\"Mashonaland West\",
\t\t\"Masvingo\",
\t\t\"Matabeleland North\",
\t\t\"Matabeleland South\",
\t\t\"Midlands\"
\t],
\t\"Finland\": [
\t\t\"South Karelia\",
\t\t\"South Ostrobothnia\",
\t\t\"Etel\\u00e4-Savo\",
\t\t\"H\\u00e4me\",
\t\t\"It\\u00e4-Uusimaa\",
\t\t\"Kainuu\",
\t\t\"Central Ostrobothnia\",
\t\t\"Central Finland\",
\t\t\"Kymenlaakso\",
\t\t\"Lapland\",
\t\t\"Tampere Region\",
\t\t\"Ostrobothnia\",
\t\t\"North Karelia\",
\t\t\"Nothern Ostrobothnia\",
\t\t\"Northern Savo\",
\t\t\"P\\u00e4ij\\u00e4t-H\\u00e4me\",
\t\t\"Satakunta\",
\t\t\"Uusimaa\",
\t\t\"South-West Finland\",
\t\t\"\\u00c5land\"
\t],
\t\"Netherlands Antilles\": [
\t\t\"Bonaire\",
\t\t\"Cura\\u00e7ao\",
\t\t\"Saba\",
\t\t\"St. Eustatius\",
\t\t\"St. Maarten\"
\t]
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/json/regions.json";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/json/regions.json", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/json/regions.json");
    }
}
